@@ -33,9 +33,7 @@
 #include "katemwmodonhddialog.h"
 #include "katesession.h"
 #include "katemainwindowadaptor.h"
-#include "kateviewdocumentproxymodel.h"
 #include "kateviewspace.h"
-//#include "modeltest.h"
 
 #include <kate/mainwindow.h>
 
@@ -61,6 +59,7 @@
 #include <KRun>
 #include <KRecentFilesAction>
 #include <KToggleFullScreenAction>
+#include <KActionCollection>
 #include <KAboutData>
 #include <kwindowsystem.h>
 
@@ -70,6 +69,10 @@
 #include <QList>
 #include <QDesktopWidget>
 
+#include <kio/job.h>
+#include <KIO/ListJob>
+#include <KFileItem>
+
 #include <assert.h>
 #include <unistd.h>
 //END
@@ -182,7 +185,8 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
 
   // connect documents menu aboutToshow
   documentMenu = (QMenu*)factory()->container("go", this);
-  connect(documentMenu, SIGNAL(aboutToShow()), this, SLOT(documentMenuAboutToShow()));
+  if (documentMenu)
+    connect(documentMenu, SIGNAL(aboutToShow()), this, SLOT(documentMenuAboutToShow()));
 
   documentsGroup = new QActionGroup(documentMenu);
   documentsGroup->setExclusive(true);
@@ -197,16 +201,7 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
   readOptions();
 
   if (sconfig)
-  {
-    int id = KateApp::self()->mainWindowID (this);
-    m_documentModel->readSessionConfig( sconfig,
-        QString("DocumentModel:MainWindow:%1").arg(id) );
-    // sync session config - or do we need an extra
-    // KateFileList::readSessionConfig() here too?
-    m_fileList->setSortRole(m_documentModel->sortRole());
-
     m_viewManager->restoreViewConfiguration (KConfigGroup(sconfig, sgroup) );
-  }
 
   finishRestore ();
 
@@ -248,46 +243,12 @@ void KateMainWindow::setupMainWindow ()
 {
   setToolViewStyle( KMultiTabBar::KDEV3ICON );
 
+  m_topViewBarContainer=new QWidget(centralWidget());
+  m_topContainerStack = new KateContainerStackedLayout(m_topViewBarContainer);
   m_viewManager = new KateViewManager (centralWidget(), this);
   ((QBoxLayout*)(centralWidget()->layout()))->setStretchFactor(m_viewManager,100);
-  m_horizontalViewBarContainer=new QWidget(centralWidget());
-  m_containerstack = new KateContainerStackedLayout(m_horizontalViewBarContainer);
-
-
-  KateMDI::ToolView *ft = createToolView("kate_filelist", KMultiTabBar::Left, SmallIcon("document-multiple"), i18n("Documents"));
-  m_fileList = new KateFileList(ft, actionCollection());
-  m_documentModel = new KateViewDocumentProxyModel(this);
-  m_documentModel->setSourceModel(KateDocManager::self());
-//  new ModelTest(m_documentModel,this);
-  m_fileList->setModel(m_documentModel);
-  m_fileList->setSelectionModel(m_documentModel->selection());
-  m_fileList->setDragEnabled(true);
-  m_fileList->setDragDropMode(QAbstractItemView::InternalMove);
-  m_fileList->setDropIndicatorShown(true);
-  m_fileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
-#ifdef __GNUC__
-#warning I do not like it, it looks like a hack, search for a better way, but for now it should work. (Even on windows most lisviews, except exploder are single click) (jowenn)
-#endif
-  if (!style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, m_fileList) )
-  {
-    //kDebug() << "HACK:***********************CONNECTING CLICKED***************************";
-    connect(m_fileList, SIGNAL(clicked(const QModelIndex&)), m_documentModel, SLOT(opened(const QModelIndex&)));
-    connect(m_fileList, SIGNAL(clicked(const QModelIndex&)), m_viewManager, SLOT(activateDocument(const QModelIndex &)));
-  }
-  connect(m_fileList, SIGNAL(activated(const QModelIndex&)), m_documentModel, SLOT(opened(const QModelIndex&)));
-  connect(m_fileList, SIGNAL(activated(const QModelIndex&)), m_viewManager, SLOT(activateDocument(const QModelIndex &)));
-  connect(m_fileList, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(showFileListPopup(const QPoint&)));
-  connect(m_fileList, SIGNAL(closeDocument(KTextEditor::Document*)),m_viewManager,SLOT(slotDocumentClose(KTextEditor::Document*)));
-  connect(m_fileList, SIGNAL(closeOtherDocument(KTextEditor::Document*)),this,SLOT(slotDocumentCloseOther(KTextEditor::Document*)));
-  connect(m_fileList, SIGNAL(closeSelectedDocument(QList<KTextEditor::Document*>)),
-                      this, SLOT(slotDocumentCloseSelected(QList<KTextEditor::Document*>)));
-  connect(m_fileList, SIGNAL(saveSelectedDocument(QList<KTextEditor::Document*>)),
-                      KateDocManager::self(), SLOT(saveSelected(QList<KTextEditor::Document*>)));
-  //filelist = new KateFileList (this, m_viewManager, ft);
-//   m_fileList->readConfig(KConfigGroup(KGlobal::config(), "FileList"));
-
-  // make per default the filelist visible, if we are in session restore, katemdi will skip this ;)
-  showToolView (ft);
+  m_bottomViewBarContainer=new QWidget(centralWidget());
+  m_bottomContainerStack = new KateContainerStackedLayout(m_bottomViewBarContainer);
 }
 
 void KateMainWindow::setupActions()
@@ -383,8 +344,9 @@ void KateMainWindow::setupActions()
   connect(m_viewManager, SIGNAL(viewCreated(KTextEditor::View *)), m_mainWindow, SIGNAL(viewCreated(KTextEditor::View *)));
   connect(m_viewManager, SIGNAL(viewChanged()), this, SLOT(slotWindowActivated()));
   connect(m_viewManager, SIGNAL(viewChanged()), this, SLOT(slotUpdateOpenWith()));
-  connect(m_viewManager, SIGNAL(viewChanged()), this, SLOT(slotUpdateHorizontalViewBar()));
-
+  connect(m_viewManager, SIGNAL(viewChanged()), this, SLOT(slotUpdateBottomViewBar()));
+  connect(m_viewManager, SIGNAL(viewChanged()), this, SLOT(slotUpdateTopViewBar()));
+  
   slotWindowActivated ();
 
   // session actions
@@ -406,10 +368,6 @@ void KateMainWindow::setupActions()
   a->setIcon( KIcon("document-save-as") );
   a->setText( i18n("Save Session &As...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAs() ) );
-  a = actionCollection()->addAction( "sessions_save_default" );
-  a->setIcon( KIcon("document-save-as") );
-  a->setText( i18n("Save Session as &Default...") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAsDefault() ) );
   a = actionCollection()->addAction( "sessions_manage" );
   a->setIcon( KIcon("view-choose") );
   a->setText( i18n("&Manage Sessions...") );
@@ -423,8 +381,16 @@ void KateMainWindow::setupActions()
 
 void KateMainWindow::slotDocumentCloseAll()
 {
-  if (queryClose_internal())
-    KateDocManager::self()->closeAllDocuments(false);
+  if ( KateDocManager::self()->documents() >= 1 && KMessageBox::warningContinueCancel(this,
+                                       i18n ("This will close all open documents. Are you sure you want to continue?"),
+                                       i18n ("Close all documents"),
+                                       KStandardGuiItem::cont(),
+                                       KStandardGuiItem::cancel(),
+                                       QString("closeAll")) != KMessageBox::Cancel)
+  {
+    if (queryClose_internal())
+      KateDocManager::self()->closeAllDocuments(false);
+  }
 }
 
 
@@ -513,7 +479,7 @@ void KateMainWindow::slotEditToolbars()
   saveMainWindowSettings(KConfigGroup(KGlobal::config(), "MainWindow"));
   KEditToolBar dlg( factory() );
 
-  connect( &dlg, SIGNAL(newToolbarConfig()), this, SLOT(slotNewToolbarConfig()) );
+  connect( &dlg, SIGNAL(newToolBarConfig()), this, SLOT(slotNewToolbarConfig()) );
   dlg.exec();
 }
 
@@ -532,6 +498,14 @@ void KateMainWindow::slotFileClose()
   m_viewManager->slotDocumentClose();
 }
 
+void KateMainWindow::slotOpenDocument(KUrl url)
+{
+  m_viewManager->openUrl(url,
+                        QString(),
+                        true,
+                        false);
+}
+
 void KateMainWindow::readOptions ()
 {
   KSharedConfig::Ptr config = KGlobal::config();
@@ -560,11 +534,6 @@ void KateMainWindow::saveOptions ()
 
   generalGroup.writeEntry("Show Full Path in Title", m_paShowPath->isChecked());
   generalGroup.writeEntry("Show Status Bar", m_paShowStatusBar->isChecked());
-
-#ifdef __GNUC__
-#warning PORTME
-#endif
-  //filelist->writeConfig(config.data(), "Filelist");
 }
 
 void KateMainWindow::toggleShowStatusBar ()
@@ -580,10 +549,7 @@ bool KateMainWindow::showStatusBar ()
 void KateMainWindow::slotWindowActivated ()
 {
   if (m_viewManager->activeView())
-  {
-    m_documentModel->opened(modelIndexForDocument(m_viewManager->activeView()->document()));
     updateCaption (m_viewManager->activeView()->document());
-  }
 
   // update proxy
   centralWidget()->setFocusProxy (m_viewManager->activeView());
@@ -628,6 +594,7 @@ Q_DECLARE_METATYPE(KateRowColumn)
 
 void KateMainWindow::documentMenuAboutToShow()
 {
+#if 0
   qRegisterMetaType<KTextEditor::Document*>("KTextEditor::Document*");
   qDeleteAll( documentsGroup->actions() );
   int rows = m_fileList->model()->rowCount(QModelIndex());
@@ -647,10 +614,12 @@ void KateMainWindow::documentMenuAboutToShow()
     action->setData(QVariant::fromValue(KateRowColumn(index.row(), index.column())));
     documentMenu->addAction(action);
   }
+#endif
 }
 
 void KateMainWindow::activateDocumentFromDocMenu (QAction *action)
 {
+#if 0
   KateRowColumn rowCol = action->data().value<KateRowColumn>();
   if (!rowCol.isValid()) return;
   QModelIndex index = m_documentModel->index(rowCol.row(), rowCol.column());
@@ -661,6 +630,7 @@ void KateMainWindow::activateDocumentFromDocMenu (QAction *action)
       m_viewManager->activateView (doc);
     m_documentModel->opened(index);
   }
+#endif
 }
 
 
@@ -693,7 +663,30 @@ void KateMainWindow::slotDropEvent( QDropEvent * event )
 
   for (KUrl::List::Iterator i = textlist.begin(); i != textlist.end(); ++i)
   {
-    m_viewManager->openUrl (*i);
+    // if url has no file component, try and recursively scan dir
+    KFileItem kitem( KFileItem::Unknown, KFileItem::Unknown, *i, true );
+    if( kitem.isDir() ) {
+      KIO::ListJob *list_job = KIO::listRecursive(*i, KIO::DefaultFlags, false);
+      connect(list_job, SIGNAL(entries(KIO::Job *, const KIO::UDSEntryList &)),
+              this, SLOT(slotListRecursiveEntries(KIO::Job *, const KIO::UDSEntryList &)));
+    }
+    else {
+      m_viewManager->openUrl (*i);
+    }
+  }
+}
+
+void KateMainWindow::slotListRecursiveEntries(KIO::Job *job, const KIO::UDSEntryList &list)
+{
+  const KUrl dir = static_cast<KIO::SimpleJob*>( job )->url();
+  foreach( const KIO::UDSEntry &entry, list )
+  {
+      KUrl currentUrl = dir;
+      currentUrl.addPath( entry.stringValue( KIO::UDSEntry::UDS_NAME ) );
+      if( !entry.isDir() )
+      {
+          m_viewManager->openUrl(currentUrl);
+      }
   }
 }
 
@@ -894,7 +887,6 @@ bool KateMainWindow::showModOnDiskPrompt()
 
 void KateMainWindow::slotDocumentCreated (KTextEditor::Document *doc)
 {
-  connect(doc, SIGNAL(modifiedChanged(KTextEditor::Document *)), this, SLOT(slotDocModified(KTextEditor::Document *)));
   connect(doc, SIGNAL(modifiedChanged(KTextEditor::Document *)), this, SLOT(updateCaption(KTextEditor::Document *)));
   connect(doc, SIGNAL(documentNameChanged(KTextEditor::Document *)), this, SLOT(updateCaption(KTextEditor::Document *)));
   connect(doc, SIGNAL(documentNameChanged(KTextEditor::Document *)), this, SLOT(slotUpdateOpenWith()));
@@ -952,9 +944,6 @@ void KateMainWindow::saveProperties(KConfigGroup& config)
       }
   }
 
-  m_documentModel->writeSessionConfig( config.config(),
-      QString("DocumentModel:MainWindow:%1").arg(id) );
-
   fileOpenRecent->saveEntries( KConfigGroup(config.config(), "Recent Files" ) );
   m_viewManager->saveViewConfiguration (config);
 }
@@ -971,10 +960,6 @@ void KateMainWindow::readProperties(const KConfigGroup& config)
 
   finishRestore ();
 
-  int id = KateApp::self()->mainWindowID (this);
-  m_documentModel->readSessionConfig( config.config(),
-      QString("DocumentModel:MainWindow:%1").arg(id) );
-
   fileOpenRecent->loadEntries( KConfigGroup(config.config(), "Recent Files" ) );
   m_viewManager->restoreViewConfiguration (config);
 }
@@ -991,34 +976,6 @@ void KateMainWindow::saveGlobalProperties( KConfig* sessionConfig )
   
 }
 
-void KateMainWindow::showFileListPopup(const QPoint& pos)
-{
-  if (m_fileList->selectionModel()->selection().count() == 0) return;
-  QMenu *menu = (QMenu*) (factory()->container("filelist_popup", m_viewManager->mainWindow()));
-  if (menu) menu->exec(m_fileList->viewport()->mapToGlobal(pos));
-}
-
-
-static QModelIndex modelIndexForDocumentRec(const QModelIndex &index, QAbstractItemModel *model)
-{
-  QAbstractProxyModel *m = qobject_cast<QAbstractProxyModel*>(model);
-  if (m == 0) return index;
-  return m->mapFromSource(modelIndexForDocumentRec(index, m->sourceModel()));
-}
-
-QModelIndex KateMainWindow::modelIndexForDocument(KTextEditor::Document *document)
-{
-  KTextEditor::Document *tmp = m_documentModel->selection()->currentIndex().data(KateDocManager::DocumentRole).value<KTextEditor::Document*>();
-  if (tmp == document) return m_documentModel->selection()->currentIndex();
-  else return modelIndexForDocumentRec(KateDocManager::self()->indexForDocument(document), m_documentModel);
-}
-
-
-void KateMainWindow::slotDocModified(KTextEditor::Document *document)
-{
-  if (document->isModified()) m_documentModel->modified(modelIndexForDocument(document));
-}
-
 void KateMainWindow::saveWindowConfig(const KConfigGroup &_config)
 {
   KConfigGroup config( _config );
@@ -1036,23 +993,42 @@ void KateMainWindow::restoreWindowConfig(const KConfigGroup &config)
   setWindowState( QFlags<Qt::WindowState>(config.readEntry("WindowState", int(Qt::WindowActive))) );
 }
 
-void KateMainWindow::slotUpdateHorizontalViewBar()
+void KateMainWindow::slotUpdateBottomViewBar()
 {
   //kDebug()<<"slotUpdateHorizontalViewBar()"<<endl;
   KTextEditor::View *view=m_viewManager->activeView();
-  BarState bs=m_viewBarMapping[view];
+  BarState bs=m_bottomViewBarMapping[view];
   if (bs.bar() && bs.state()) {
-    m_containerstack->setCurrentWidget(bs.bar());
-    m_containerstack->currentWidget()->show();
-    m_horizontalViewBarContainer->show();
+    m_bottomContainerStack->setCurrentWidget(bs.bar());
+    m_bottomContainerStack->currentWidget()->show();
+    m_bottomViewBarContainer->show();
   } else {
-    QWidget *wid=m_containerstack->currentWidget();
+    QWidget *wid=m_bottomContainerStack->currentWidget();
     if (wid) wid->hide();
     //kDebug()<<wid<<"hiding container"<<endl;
-    m_horizontalViewBarContainer->hide();
+    m_bottomViewBarContainer->hide();
   }
 }
 
+
+void KateMainWindow::slotUpdateTopViewBar()
+{
+  //kDebug()<<"slotUpdateHorizontalViewBar()"<<endl;
+  KTextEditor::View *view=m_viewManager->activeView();
+  BarState bs=m_topViewBarMapping[view];
+  if (bs.bar() && bs.state()) {
+    m_topContainerStack->setCurrentWidget(bs.bar());
+    m_topContainerStack->currentWidget()->show();
+    m_topViewBarContainer->show();
+  } else {
+    QWidget *wid=m_topContainerStack->currentWidget();
+    if (wid) wid->hide();
+    //kDebug()<<wid<<"hiding container"<<endl;
+    m_topViewBarContainer->hide();
+  }
+}
+
+
 void KateMainWindow::queueModifiedOnDisc(KTextEditor::Document *doc)
 {
   if (!modNotification) return;
