@@ -44,6 +44,9 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QToolButton>
+
+#include <kdeversion.h>
+
 //END Includes
 
 
@@ -71,6 +74,14 @@ KateFileBrowser::KateFileBrowser(Kate::MainWindow *mainWindow,
   m_dirOperator->setView(KFile::/* Simple */Detail);
   m_dirOperator->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
   m_dirOperator->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
+
+#if KDE_IS_VERSION(4, 4, 60)
+  // Mime filter for the KDirOperator
+  QStringList filter;
+  filter << "text/plain" << "text/html" << "inode/directory";
+  m_dirOperator->setNewFileMenuSupportedMimeTypes(filter);
+#endif
+
   setFocusProxy(m_dirOperator);
   connect(m_dirOperator, SIGNAL(viewChanged(QAbstractItemView *)),
           this, SLOT(selectorViewChanged(QAbstractItemView *)));
@@ -125,7 +136,7 @@ void KateFileBrowser::setupToolbar()
   m_toolbar->clear();
 
   // now add all actions to the toolbar
-  foreach (QString it, actions)
+  foreach (const QString& it, actions)
   {
     QAction *ac = 0;
     if (it.isEmpty()) continue;
