@@ -109,6 +109,7 @@ void PluginViewKateFileTemplates::refreshMenu()
 
 PluginViewKateFileTemplates::~PluginViewKateFileTemplates()
 {
+  mainWindow()->guiFactory()->removeClient (this);
 }
 //END PluginViewKateFileTemplates
 
@@ -630,7 +631,8 @@ void KateTemplateInfoWidget::slotHlSet( QAction *action )
 {
   KTextEditor::Document *doc=kft->application()->activeMainWindow()->activeView()->document();
   if (doc)
-    btnHighlight->setText( action->text() ); // fixme
+    highlightName = doc->highlightingModes()[action->data().toInt()];  
+  btnHighlight->setText( action->text() ); // fixme
 }
 //END KateTemplateInfoWidget
 
@@ -935,8 +937,8 @@ void KateTemplateWizard::accept()
     s += " Documentname=" + kti->leDocumentName->text();
   if ( ! kti->ibIcon->icon().isEmpty() )
     s += " Icon=" + kti->ibIcon->icon();
-  if ( ! kti->btnHighlight->text().isEmpty() )
-    s += " Highlight=" + kti->btnHighlight->text();
+  if ( ! kti->highlightName.isEmpty() && kti->highlightName != "None" )
+    s += " Highlight=" + kti->highlightName;
 
   str = "katetemplate:" + s;
 
