@@ -136,7 +136,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
          "Mime-Version: 1.0" );
       tempHeader.setMsgstr( tmp);
       // We keep the comment of the first entry, as it might really be a header comment (at least partially)
-      const QString comment( "# Header entry was created by KBabel!\n#\n" + _comment );
+      const QString comment( "# Header entry was created by Lokalize.\n#\n" + _comment );
       tempHeader.setComment( comment );
       recoveredErrorInHeader = true;
    }
@@ -361,7 +361,10 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 
        kDebug() << "Parsing line: " << line;
 
-       if (KDE_ISUNLIKELY( line.startsWith( "<<<<<<<" ) || line.startsWith( "=======" ) || line.startsWith( ">>>>>>>" ) ))
+       static const QString lesslessless="<<<<<<<";
+       static const QString isisis="=======";
+       static const QString moremoremore=">>>>>>>";
+       if (KDE_ISUNLIKELY( line.startsWith( lesslessless ) || line.startsWith( isisis ) || line.startsWith( moremoremore ) ))
        {
           // We have found a CVS/SVN conflict marker. Abort.
           // (It cannot be any useful data of the PO file, as otherwise the line would start with at least a quote)
