@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -56,9 +56,7 @@ LanguageListModel::LanguageListModel(QObject* parent)
 {
     KIconLoader::global()->addExtraDesktopThemes();
     //kWarning()<<KIconLoader::global()->hasContext(KIconLoader::International);
-    kDebug()<<KIconLoader::global()->queryIconsByContext(KIconLoader::NoGroup,KIconLoader::International);
-    //kWarning()<<KGlobal::locale()->allLanguagesList();
-    kDebug()<<QLocale("uk").name();
+    //kDebug()<<KIconLoader::global()->queryIconsByContext(KIconLoader::NoGroup,KIconLoader::International);
     m_sortModel->setSourceModel(this);
     m_sortModel->sort(0);
 }
@@ -68,11 +66,18 @@ QVariant LanguageListModel::data(const QModelIndex& index, int role) const
     if (role==Qt::DecorationRole)
     {
         static QMap<QString,QIcon> iconCache;
-        
+
         QString langCode=stringList().at(index.row());
         if (!iconCache.contains(langCode))
         {
-            QString code=QLocale(langCode).name();
+            // NOTE workaround for QTBUG-9370 - it will be removed later
+            QString code;
+            if(langCode == "mn")
+                code = "mn_MN";
+            else if(langCode == "ne")
+                code = "ne_NP";
+            else
+                code=QLocale(langCode).name();
             QString path;
             if (code.contains('_')) code=code.mid(3).toLower();
             if (code!="C")
