@@ -1,14 +1,14 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -136,6 +136,7 @@ public slots:
     Q_SCRIPTABLE int entryCount();
     Q_SCRIPTABLE QString entrySource(int entry, int form);
     Q_SCRIPTABLE QString entryTarget(int entry, int form);
+    Q_SCRIPTABLE void setEntryTarget(int entry, int form, const QString& content);
     Q_SCRIPTABLE int entryPluralFormCount(int entry);
     Q_SCRIPTABLE bool entryReady(int entry);
     Q_SCRIPTABLE void addEntryNote(int entry, const QString& note);
@@ -238,6 +239,8 @@ private slots:
     void dispatchSrcFileOpenRequest(const QString& srcPath, int line);
     void indexWordsForCompletion();
 
+    void fileAutoSaveFailedWarning(const QString&);
+
 private:
     void setupAccel();
     void setupActions();
