@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -34,11 +34,11 @@ class SyntaxHighlighter;//TODO rename
 class KCompletionBox;
 class MyCompletionBox;
 
-class XliffTextEdit: public KTextEdit
+class TranslationUnitTextEdit: public KTextEdit
 {
     Q_OBJECT
 public:
-    XliffTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent=0);
+    TranslationUnitTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent=0);
     //NOTE remove this when Qt is fixed (hack for unbreakable spaces bug #162016)
     QString toPlainText();
 
@@ -63,6 +63,8 @@ public slots:
 
     void emitCursorPositionChanged();//for leds
 
+    void doExplicitCompletion();
+
 protected:
     void keyPressEvent(QKeyEvent *keyEvent);
     void keyReleaseEvent(QKeyEvent* e);
@@ -90,7 +92,7 @@ private slots:
     //for Undo/Redo tracking
     void contentsChanged(int position,int charsRemoved,int charsAdded);
     void completionActivated(const QString&);
-    void projectConfigChanged();
+    void fileLoaded();
 
 signals:
     void toggleApprovementRequested();
