@@ -1,20 +1,16 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2008                                               *
+ *   copyright (C) 2003-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "association.h"
-// qt/kde includes
-#include <kdebug.h>
-#include <klocale.h>
-#include <QtCore/QRegExp>
+
 // app includes
 #include "classifier.h"
 #include "folder.h"
@@ -24,63 +20,22 @@
 #include "uniqueid.h"
 #include "model_utils.h"
 #include "cmds.h"
+
+// kde includes
+#include <kdebug.h>
+#include <klocale.h>
+
+// qt includes
+#include <QtCore/QRegExp>
+
 using namespace Uml;
 
 // static members
 const Uml::Association_Type UMLAssociation::atypeFirst = Uml::at_Generalization;
 const Uml::Association_Type UMLAssociation::atypeLast = Uml::at_Relationship;
-const unsigned UMLAssociation::nAssocTypes = (unsigned)atypeLast -
-        (unsigned)atypeFirst + 1;
-
-// constructor
-UMLAssociation::UMLAssociation( Uml::Association_Type type,
-                                UMLObject * roleA, UMLObject * roleB )
-        : UMLObject("")
-{
-    init(type, roleA, roleB);
-
-    m_pRole[Uml::A]->setID( UniqueID::gen() );
-    m_pRole[Uml::B]->setID( UniqueID::gen() );
-}
-
-UMLAssociation::UMLAssociation( Uml::Association_Type type /* = Uml::at_Unknown */)
-        : UMLObject("", Uml::id_Reserved)
-{
-    init(type, NULL, NULL);
-}
-
-// destructor
-UMLAssociation::~UMLAssociation( ) {
-    if (m_pRole[A] == NULL) {
-        uError() << "UMLAssociation destructor: m_pRole[A] is NULL already"
-        << endl;
-    } else {
-        delete m_pRole[A];
-        m_pRole[A] = NULL;
-    }
-    if (m_pRole[B] == NULL) {
-        uError() << "UMLAssociation destructor: m_pRole[B] is NULL already"
-        << endl;
-    } else {
-        delete m_pRole[B];
-        m_pRole[B] = NULL;
-    }
-}
-
-bool UMLAssociation::operator==(const UMLAssociation &rhs) {
-    if (this == &rhs) {
-        return true;
-    }
-    return ( UMLObject::operator== ( rhs ) &&
-             m_AssocType == rhs.m_AssocType &&
-             m_Name == rhs.m_Name &&
-             m_pRole[A] == rhs.m_pRole[A] &&
-             m_pRole[B] == rhs.m_pRole[B] );
-}
-
+const unsigned UMLAssociation::nAssocTypes = (unsigned)atypeLast - (unsigned)atypeFirst + 1;
 const QString UMLAssociation::assocTypeStr[UMLAssociation::nAssocTypes] = {
-            /* The elements must be listed in the same order as in the
-               Uml::Association_Type.  */
+            // Elements must be listed in the same order as in the Uml::Association_Type.
             i18n("Generalization"),             // at_Generalization
             i18n("Aggregation"),                // at_Aggregation
             i18n("Dependency"),                 // at_Dependency
@@ -103,36 +58,118 @@ const QString UMLAssociation::assocTypeStr[UMLAssociation::nAssocTypes] = {
             i18n("Relationship" )               // at_Relationship
         };
 
-Uml::Association_Type UMLAssociation::getAssocType() const {
+/**
+ * Sets up an association.
+ * A new unique ID is assigned internally.
+ * @param type    The Uml::Association_Type to construct.
+ * @param roleA   Pointer to the UMLObject in role A.
+ * @param roleB   Pointer to the UMLObject in role B.
+ */
+UMLAssociation::UMLAssociation( Uml::Association_Type type,
+                                UMLObject * roleA, UMLObject * roleB )
+  : UMLObject("")
+{
+    init(type, roleA, roleB);
+
+    m_pRole[Uml::A]->setID( UniqueID::gen() );
+    m_pRole[Uml::B]->setID( UniqueID::gen() );
+}
+
+/**
+ * Constructs an association - for loading only.
+ * This constructor should not normally be used as it constructs
+ * an incomplete association (i.e. the role objects are missing.)
+ * @param type   The Uml::Association_Type to construct.
+ *               Default: Uml::at_Unknown.
+ */
+UMLAssociation::UMLAssociation( Uml::Association_Type type)
+  : UMLObject("", Uml::id_Reserved)
+{
+    init(type, NULL, NULL);
+}
+
+/**
+ * Standard destructor.
+ */
+UMLAssociation::~UMLAssociation( )
+{
+    if (m_pRole[A] == NULL) {
+        uError() << "UMLAssociation destructor: m_pRole[A] is NULL already";
+    } else {
+        delete m_pRole[A];
+        m_pRole[A] = NULL;
+    }
+    if (m_pRole[B] == NULL) {
+        uError() << "UMLAssociation destructor: m_pRole[B] is NULL already";
+    } else {
+        delete m_pRole[B];
+        m_pRole[B] = NULL;
+    }
+}
+
+/**
+ * Overloaded '==' operator
+ */
+bool UMLAssociation::operator==(const UMLAssociation &rhs)
+{
+    if (this == &rhs) {
+        return true;
+    }
+    return ( UMLObject::operator== ( rhs ) &&
+             m_AssocType == rhs.m_AssocType &&
+             m_Name == rhs.m_Name &&
+             m_pRole[A] == rhs.m_pRole[A] &&
+             m_pRole[B] == rhs.m_pRole[B] );
+}
+
+/**
+ * Returns the Association_Type of the UMLAssociation.
+ * @return  The Association_Type of the UMLAssociation.
+ */
+Uml::Association_Type UMLAssociation::getAssocType() const
+{
     return m_AssocType;
 }
 
-QString UMLAssociation::toString ( ) const
+/**
+ * Returns a String representation of this UMLAssociation.
+ */
+QString UMLAssociation::toString() const
 {
     QString string;
     if(m_pRole[A])
     {
-        string += m_pRole[A]->getObject()->getName();
+        string += m_pRole[A]->object()->name();
         string += ':';
-        string += m_pRole[A]->getName();
+        string += m_pRole[A]->name();
     }
-    string += ':' + typeAsString(m_AssocType) + ':';
+    string += ':' + toString(m_AssocType) + ':';
     if(m_pRole[B])
     {
-        string += m_pRole[B]->getObject( )->getName();
+        string += m_pRole[B]->object( )->name();
         string += ':';
-        string += m_pRole[B]->getName();
+        string += m_pRole[B]->name();
     }
     return string;
 }
 
-QString UMLAssociation::typeAsString (Uml::Association_Type atype)
+/**
+ * Converts a Uml::Association_Type to its string representation.
+ *
+ * @param atype   The Association_Type enum value to convert.
+ * @return  The string representation of the Association_Type.
+ */
+QString UMLAssociation::toString (Uml::Association_Type atype)
 {
     if (atype < atypeFirst || atype > atypeLast)
         return QString();
     return assocTypeStr[(unsigned)atype - (unsigned)atypeFirst];
 }
 
+/**
+ * Returns true if the given Association_Type has a representation as a
+ * UMLAssociation.
+ */
 bool UMLAssociation::assocTypeHasUMLRepresentation(Uml::Association_Type atype)
 {
     return (atype == Uml::at_Generalization ||
@@ -148,24 +185,36 @@ bool UMLAssociation::assocTypeHasUMLRepresentation(Uml::Association_Type atype)
             atype == Uml::at_Child2Category);
 }
 
-bool UMLAssociation::resolveRef() {
+/**
+ * Resolve types. Required when dealing with foreign XMI files.
+ * Needs to be called after all UML objects are loaded from file.
+ * Overrides the method from UMLObject.
+ * Calls resolveRef() for each role.
+ * @return  True for success.
+ */
+bool UMLAssociation::resolveRef()
+{
     bool successA = getUMLRole(A)->resolveRef();
     bool successB = getUMLRole(B)->resolveRef();
     if (successA && successB) {
-        UMLObject *objA = getUMLRole(A)->getObject();
-        UMLObject *objB = getUMLRole(B)->getObject();
+        UMLObject *objA = getUMLRole(A)->object();
+        UMLObject *objB = getUMLRole(B)->object();
         // Check if need to change the assoc type to Realization
-        if (m_AssocType == Uml::at_Generalization &&
-                (objA && objA->getBaseType() == Uml::ot_Interface ||
-                 objB && objB->getBaseType() == Uml::ot_Interface))
+        if (isRealization(objA, objB)) {
             m_AssocType = Uml::at_Realization;
+        }
         m_pUMLPackage->addAssocToConcepts(this);
         return true;
     }
     return false;
 }
 
-void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
+/**
+ * Creates the <UML:Generalization> or <UML:Association> XMI element
+ * including its role objects.
+ */
+void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
+{
     if (m_AssocType == Uml::at_Generalization) {
         QDomElement assocElement = UMLObject::save("UML:Generalization", qDoc);
         assocElement.setAttribute( "discriminator", "" );
@@ -211,19 +260,24 @@ void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
     qElement.appendChild( associationElement );
 }
 
-bool UMLAssociation::load( QDomElement & element ) {
-    if (getID() == Uml::id_None)
+/**
+ * Creates the <UML:Generalization> or <UML:Association> XMI element
+ * including its role objects.
+ */
+bool UMLAssociation::load( QDomElement & element )
+{
+    if (id() == Uml::id_None)
         return false; // old style XMI file. No real info in this association.
 
-    UMLDoc * doc = UMLApp::app()->getDocument();
+    UMLDoc * doc = UMLApp::app()->document();
     UMLObject * obj[2] = { NULL, NULL };
     if (m_AssocType == Uml::at_Generalization ||
-        m_AssocType == Uml::at_Realization ||
-        m_AssocType == Uml::at_Dependency ||
+        m_AssocType == Uml::at_Realization    ||
+        m_AssocType == Uml::at_Dependency     ||
         m_AssocType == Uml::at_Child2Category ||
         m_AssocType == Uml::at_Category2Parent
         ) {
-        for (unsigned r = Uml::A; r <= Uml::B; r++) {
+        for (unsigned r = Uml::A; r <= Uml::B; ++r) {
             const QString fetch = (m_AssocType == Uml::at_Generalization ?
                                    r == Uml::A ? "child" : "parent"
                        : r == Uml::A ? "client" : "supplier");
@@ -241,10 +295,10 @@ bool UMLAssociation::load( QDomElement & element ) {
             } else {
                 m_pRole[role]->setObject(obj[r]);
                 if (m_pUMLPackage == NULL) {
-                    Uml::Model_Type mt = Model_Utils::convert_OT_MT(obj[r]->getBaseType());
-                    m_pUMLPackage = doc->getRootFolder(mt);
+                    Uml::Model_Type mt = Model_Utils::convert_OT_MT(obj[r]->baseType());
+                    m_pUMLPackage = doc->rootFolder(mt);
                     uDebug() << "assoctype " << m_AssocType
-                        << ": setting model type " << mt << endl;
+                        << ": setting model type " << mt;
                 }
             }
         }
@@ -272,8 +326,8 @@ bool UMLAssociation::load( QDomElement & element ) {
                 }
                 if (idStr.isEmpty()) {
                     uError() << "type " << m_AssocType
-                        << ", id " << ID2STR(getID()) << ": "
-                        << "xmi id not given for " << tag << endl;
+                        << ", id " << ID2STR(id()) << ": "
+                        << "xmi id not given for " << tag;
                     continue;
                 }
                 // Since we know for sure that we're dealing with a non
@@ -286,12 +340,10 @@ bool UMLAssociation::load( QDomElement & element ) {
             }
         }
 
-        // its a realization if either endpoint is an interface
-        if (m_AssocType == Uml::at_Generalization &&
-                (obj[A] && obj[A]->getBaseType() == Uml::ot_Interface ||
-                 obj[B] && obj[B]->getBaseType() == Uml::ot_Interface))
+        // it is a realization if either endpoint is an interface
+        if (isRealization(obj[A], obj[B])) {
             m_AssocType = Uml::at_Realization;
-
+        }
         return true;
     }
 
@@ -307,7 +359,7 @@ bool UMLAssociation::load( QDomElement & element ) {
         if (!tagEq(tag, "Association.connection") &&
                 !tagEq(tag, "Namespace.ownedElement") &&
                 !tagEq(tag, "Namespace.contents")) {
-            uWarning() << "unknown child node " << tag << endl;
+            uWarning() << "unknown child node " << tag;
             continue;
         }
         // Load role A.
@@ -322,7 +374,7 @@ bool UMLAssociation::load( QDomElement & element ) {
         tag = tempElement.tagName();
         if (!tagEq(tag, "AssociationEndRole") &&
                 !tagEq(tag, "AssociationEnd")) {
-            uWarning() << "unknown child (A) tag " << tag << endl;
+            uWarning() << "unknown child (A) tag " << tag;
             return false;
         }
         if (! getUMLRole(A)->loadFromXMI(tempElement))
@@ -339,15 +391,15 @@ bool UMLAssociation::load( QDomElement & element ) {
         tag = tempElement.tagName();
         if (!tagEq(tag, "AssociationEndRole") &&
                 !tagEq(tag, "AssociationEnd")) {
-            uWarning() << "unknown child (B) tag " << tag << endl;
+            uWarning() << "unknown child (B) tag " << tag;
             return false;
         }
         if (! getUMLRole(B)->loadFromXMI(tempElement))
             return false;
 
         if (m_pUMLPackage == NULL) {
-            Uml::Model_Type mt = Model_Utils::convert_OT_MT(getObject(B)->getBaseType());
-            m_pUMLPackage = doc->getRootFolder(mt);
+            Uml::Model_Type mt = Model_Utils::convert_OT_MT(getObject(B)->baseType());
+            m_pUMLPackage = doc->rootFolder(mt);
             uDebug() << "setting model type " << mt;
         }
 
@@ -401,7 +453,7 @@ bool UMLAssociation::load( QDomElement & element ) {
         };
 
         unsigned index;
-        for (index = 0; index < nAssocTypes; index++)
+        for (index = 0; index < nAssocTypes; ++index)
             if (assocTypeStr == assocTypeString[index])
                 break;
         if (index < nAssocTypes)
@@ -409,8 +461,7 @@ bool UMLAssociation::load( QDomElement & element ) {
     } else {
         int assocTypeNum = assocTypeStr.toInt();
         if (assocTypeNum < (int)atypeFirst || assocTypeNum > (int)atypeLast) {
-            uWarning() << "bad assoctype of UML:Association "
-            << ID2STR(getID()) << endl;
+            uWarning() << "bad assoctype of UML:Association " << ID2STR(id());
             return false;
         }
         assocType = (Uml::Association_Type)assocTypeNum;
@@ -472,69 +523,127 @@ bool UMLAssociation::load( QDomElement & element ) {
     return true;
 }
 
-UMLObject* UMLAssociation::getObject(Uml::Role_Type role) {
+/**
+ * Returns the UMLObject assigned to the given role.
+ * @return  Pointer to the UMLObject in the given role.
+ */
+UMLObject* UMLAssociation::getObject(Uml::Role_Type role) const
+{
     if (m_pRole[role] == NULL)
         return NULL;
-    return m_pRole[role]->getObject();
+    return m_pRole[role]->object();
 }
 
-Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) {
+/**
+ * Returns the ID of the UMLObject assigned to the given role.
+ * Shorthand for getObject(role)->getID().
+ * @return  ID of the UMLObject in the given role.
+ */
+Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
+{
     UMLRole *roleObj = m_pRole[role];
-    UMLObject *o = roleObj->getObject();
+    UMLObject *o = roleObj->object();
     if (o == NULL) {
-        QString auxID = roleObj->getSecondaryId();
+        QString auxID = roleObj->secondaryId();
         if (auxID.isEmpty()) {
-            uError() << "role " << role << ": getObject returns NULL" << endl;
+            uError() << "role " << role << ": getObject returns NULL";
             return Uml::id_None;
         } else {
-            uDebug() << "role " << role << ": using secondary ID " << auxID << endl;
+            uDebug() << "role " << role << ": using secondary ID " << auxID;
             return STR2ID(auxID);
         }
     }
-    return o->getID();
+    return o->id();
 }
 
-/* CURRENTLY UNUSED
-Uml::IDType UMLAssociation::getRoleId(Role_Type role) const {
-    return m_pRole[role]->getID();
-}
+/**
+ * Returns the ID of the UMLObject assigned to the given role.
+ * CURRENTLY UNUSED.
+ * @return  ID of the UMLObject of the given role.
  */
-
-Uml::Changeability_Type UMLAssociation::getChangeability(Uml::Role_Type role) const {
-    return m_pRole[role]->getChangeability();
+Uml::IDType UMLAssociation::getRoleId(Role_Type role) const
+{
+    return m_pRole[role]->id();
 }
 
-Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const {
-    return m_pRole[role]->getVisibility();
+/**
+ * Returns the changeability.
+ */
+Uml::Changeability_Type UMLAssociation::getChangeability(Uml::Role_Type role) const
+{
+    return m_pRole[role]->changeability();
 }
 
-QString UMLAssociation::getMulti(Uml::Role_Type role) const {
-    return m_pRole[role]->getMultiplicity();
+/**
+ * Returns the Visibility of the given role.
+ * @return  Visibility of the given role.
+ */
+Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const
+{
+    return m_pRole[role]->visibility();
 }
 
-QString UMLAssociation::getRoleName(Uml::Role_Type role) const {
-    return m_pRole[role]->getName();
+/**
+ * Returns the multiplicity assigned to the given role.
+ * @return  The multiplicity assigned to the given role.
+ */
+QString UMLAssociation::getMulti(Uml::Role_Type role) const
+{
+    return m_pRole[role]->multiplicity();
 }
 
-QString UMLAssociation::getRoleDoc(Uml::Role_Type role) const {
-    return m_pRole[role]->getDoc();
+/**
+ * Returns the name assigned to the role A.
+ * @return  The name assigned to the given role.
+ */
+QString UMLAssociation::getRoleName(Uml::Role_Type role) const
+{
+    return m_pRole[role]->name();
 }
 
-UMLRole * UMLAssociation::getUMLRole(Uml::Role_Type role) {
+/**
+ * Returns the documentation assigned to the given role.
+ * @return  Documentation text of given role.
+ */
+QString UMLAssociation::getRoleDoc(Uml::Role_Type role) const
+{
+    return m_pRole[role]->doc();
+}
+
+/**
+ * Get the underlying UMLRole object for the given role.
+ * @return  Pointer to the UMLRole object for the given role.
+ */
+UMLRole * UMLAssociation::getUMLRole(Uml::Role_Type role) const
+{
     return m_pRole[role];
 }
 
-void UMLAssociation::setOldLoadMode(bool value /* = true */) {
+/**
+ * Set the attribute m_bOldLoadMode.
+ * @param value   the new value to set
+ */
+void UMLAssociation::setOldLoadMode(bool value /* = true */)
+{
     m_bOldLoadMode = value;
 }
 
-bool UMLAssociation::getOldLoadMode() const {
+/**
+ * Return the backward compatibility flag for loading files.
+ */
+bool UMLAssociation::getOldLoadMode() const
+{
     return m_bOldLoadMode;
 }
 
-void UMLAssociation::setAssocType(Uml::Association_Type assocType) {
+/**
+ * Sets the assocType of the UMLAssociation.
+ * @param assocType The Association_Type of the UMLAssociation.
+ */
+void UMLAssociation::setAssocType(Uml::Association_Type assocType)
+{
     m_AssocType = assocType;
-    if(m_AssocType == at_UniAssociation)
+    if (m_AssocType == at_UniAssociation)
     {
         // In this case we need to auto-set the multiplicity/rolenames
         // of the roles
@@ -545,32 +654,73 @@ void UMLAssociation::setAssocType(Uml::Association_Type assocType) {
     UMLObject::emitModified();
 }
 
-void UMLAssociation::setObject(UMLObject *obj, Uml::Role_Type role) {
+/**
+ * Sets the UMLObject playing the given role in the association.
+ * @param obj  Pointer to the UMLObject of the given role.
+ * @param role The Uml::Role_Type played by the association
+ */
+void UMLAssociation::setObject(UMLObject *obj, Uml::Role_Type role)
+{
     m_pRole[role]->setObject(obj);
 }
 
-void UMLAssociation::setVisibility(Uml::Visibility value, Uml::Role_Type role) {
+/**
+ * Sets the visibility of the given role of the UMLAssociation.
+ * @param value  Visibility of role.
+ * @param role   The Uml::Role_Type to which the visibility is being applied
+ */
+void UMLAssociation::setVisibility(Uml::Visibility value, Uml::Role_Type role)
+{
     m_pRole[role]->setVisibility(value);
 }
 
-void UMLAssociation::setChangeability(Uml::Changeability_Type value, Uml::Role_Type role) {
+/**
+ * Sets the changeability of the given role of the UMLAssociation.
+ * @param value     Changeability_Type of the given role.
+ * @param role      The Uml::Role_Type to which the changeability is being set
+ */
+void UMLAssociation::setChangeability(Uml::Changeability_Type value, Uml::Role_Type role)
+{
     m_pRole[role]->setChangeability(value);
 }
 
-void UMLAssociation::setMulti(const QString &value, Uml::Role_Type role) {
-    UMLApp::app()->executeCommand(new CmdChangeMulti(m_pRole[role], value));
-    //m_pRole[role]->setMultiplicity(value);
+/**
+ * Sets the multiplicity of the given role of the UMLAssociation.
+ * @param multi    The multiplicity of the given role.
+ * @param role     The Uml::Role_Type to which the multiplicity is being applied
+ */
+void UMLAssociation::setMulti(const QString &multi, Uml::Role_Type role)
+{
+    UMLApp::app()->executeCommand(new CmdChangeMulti(m_pRole[role], multi));
+    //m_pRole[role]->setMultiplicity(multi);
 }
 
-void UMLAssociation::setRoleName(const QString &value, Uml::Role_Type role) {
-    m_pRole[role]->setName(value);
+/**
+ * Sets the name of the given role of the UMLAssociation.
+ * @param roleName  The name to set for the given role.
+ * @param role      The Uml::Role_Type for which to set the name.
+ */
+void UMLAssociation::setRoleName(const QString &roleName, Uml::Role_Type role)
+{
+    m_pRole[role]->setName(roleName);
 }
 
-void UMLAssociation::setRoleDoc(const QString &doc, Uml::Role_Type role) {
+/**
+ * Sets the documentation on the given role in the association.
+ * @param doc      The string with the documentation.
+ * @param role     The Uml::Role_Type to which the documentation is being applied
+ */
+void UMLAssociation::setRoleDoc(const QString &doc, Uml::Role_Type role)
+{
     m_pRole[role]->setDoc(doc);
 }
 
-QString UMLAssociation::ChangeabilityToString(Uml::Changeability_Type type) {
+/**
+ * Convert Changeability_Type value into QString representation.
+ * @param type   The Changeability_Type enum value to convert.
+ */
+QString UMLAssociation::toString(Uml::Changeability_Type type)
+{
     switch (type) {
     case Uml::chg_Frozen:
         return "frozen";
@@ -585,17 +735,45 @@ QString UMLAssociation::ChangeabilityToString(Uml::Changeability_Type type) {
     }
 }
 
-void UMLAssociation::init(Uml::Association_Type type, UMLObject *roleAObj, UMLObject *roleBObj) {
+/**
+ * When the association type is "Generalization" and at least one of the
+ * given objects an interface, then it is a "Realization".
+ * @param objA   UML object as role A
+ * @param objB   UML object as role B
+ * @return flag whether association is a realization
+ */
+bool UMLAssociation::isRealization(UMLObject* objA, UMLObject* objB) const
+{
+    bool aIsInterface = false;
+    if (objA && (objA->baseType() == Uml::ot_Interface)) {
+        aIsInterface = true;
+    }
+    bool bIsInterface = false;
+    if (objB && (objB->baseType() == Uml::ot_Interface)) {
+        bIsInterface = true;
+    }
+    return (m_AssocType == Uml::at_Generalization) &&
+           (aIsInterface || bIsInterface);
+}
+
+/**
+ * Common initializations at construction time.
+ * @param type      The Association_Type to represent.
+ * @param roleAObj  Pointer to the role A UMLObject.
+ * @param roleBObj  Pointer to the role B UMLObject.
+ */
+void UMLAssociation::init(Uml::Association_Type type, UMLObject *roleAObj, UMLObject *roleBObj)
+{
     m_AssocType = type;
     m_BaseType = ot_Association;
     m_Name = "";
     m_bOldLoadMode = false;
     nrof_parent_widgets = -1;
-    if (!UMLApp::app()->getDocument()->loading())
-        m_pUMLPackage = UMLApp::app()->getDocument()->currentRoot();
+    if (!UMLApp::app()->document()->loading()) {
+        m_pUMLPackage = UMLApp::app()->document()->currentRoot();
+    }
     m_pRole[Uml::A] = new UMLRole (this, roleAObj, Uml::A);
     m_pRole[Uml::B] = new UMLRole (this, roleBObj, Uml::B);
 }
 
-
 #include "association.moc"
