@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2008                                               *
+ *   copyright (C) 2003-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -65,7 +65,7 @@ void UMLClassifierListItem::copyInto(UMLObject *lhs) const
 QString UMLClassifierListItem::toString(Uml::Signature_Type sig)
 {
     Q_UNUSED(sig);
-    return getName();
+    return name();
 }
 
 /**
@@ -87,10 +87,10 @@ QString UMLClassifierListItem::getTypeName() const
 {
     if (m_pSecondary == NULL)
         return m_SecondaryId;
-    const UMLPackage *typePkg = m_pSecondary->getUMLPackage();
+    const UMLPackage *typePkg = m_pSecondary->umlPackage();
     if (typePkg != NULL && typePkg != m_pUMLPackage)
-        return m_pSecondary->getFullyQualifiedName();
-    return m_pSecondary->getName();
+        return m_pSecondary->fullyQualifiedName();
+    return m_pSecondary->name();
 }
 
 /**
@@ -119,7 +119,7 @@ void UMLClassifierListItem::setTypeName(const QString &type)
         m_SecondaryId.clear();
         return;
     }
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
     m_pSecondary = pDoc->findUMLObject(type);
     if (m_pSecondary == NULL) {
         // Make data type for easily identified cases
