@@ -46,7 +46,7 @@
 SimpleCodeGenerator::SimpleCodeGenerator(bool createDirHierarchyForPackages)
 {
     m_indentLevel = 0;
-    UMLDoc * parentDoc = UMLApp::app()->getDocument();
+    UMLDoc * parentDoc = UMLApp::app()->document();
     parentDoc->disconnect(this); // disconnect from UMLDoc.. we arent planning to be synced at all
     m_createDirHierarchyForPackages = createDirHierarchyForPackages;
     initFields(parentDoc);
@@ -87,7 +87,7 @@ QString SimpleCodeGenerator::findFileName(UMLPackage* concept, const QString &ex
     //else, determine the "natural" file name
     QString name;
     // Get the package name
-    QString package = concept->getPackage(".");
+    QString package = concept->package(".");
 
     // Replace all white spaces with blanks
     package = package.simplified();
@@ -100,12 +100,12 @@ QString SimpleCodeGenerator::findFileName(UMLPackage* concept, const QString &ex
 
     // if package is given add this as a directory to the file name
     if (!package.isEmpty() && m_createDirHierarchyForPackages) {
-        name = package + '.' + concept->getName();
+        name = package + '.' + concept->name();
         name.replace(QRegExp("\\."),"/");
         package.replace(QRegExp("\\."), "/");
         package = '/' + package;
     } else {
-        name = concept->getFullyQualifiedName("-");
+        name = concept->fullyQualifiedName("-");
     }
 
     if (! UMLApp::app()->activeLanguageIsCaseSensitive()) {
@@ -115,7 +115,7 @@ QString SimpleCodeGenerator::findFileName(UMLPackage* concept, const QString &ex
 
     // if a package name exists check the existence of the package directory
     if (!package.isEmpty() && m_createDirHierarchyForPackages) {
-        QDir pathDir(UMLApp::app()->getCommonPolicy()->getOutputDirectory().absolutePath() + package);
+        QDir pathDir(UMLApp::app()->commonPolicy()->getOutputDirectory().absolutePath() + package);
         // does our complete output directory exist yet? if not, try to create it
         if (!pathDir.exists())
         {
@@ -156,7 +156,7 @@ QString SimpleCodeGenerator::findFileName(UMLPackage* concept, const QString &ex
  */
 QString SimpleCodeGenerator::overwritableName(UMLPackage* concept, const QString &name, const QString &ext)
 {
-    CodeGenerationPolicy *commonPolicy = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *commonPolicy = UMLApp::app()->commonPolicy();
     QDir outputDir = commonPolicy->getOutputDirectory();
     QString filename = name + ext;
     if(!outputDir.exists(filename)) {
@@ -246,7 +246,7 @@ bool SimpleCodeGenerator::hasAbstractOps(UMLClassifier *c)
 {
     UMLOperationList opl(c->getOpList());
     foreach (UMLOperation* op, opl ) {
-        if(op->getAbstract())
+        if(op->isAbstract())
             return true;
     }
     return false;
@@ -270,9 +270,9 @@ CodeDocument * SimpleCodeGenerator::newClassifierCodeDocument(UMLClassifier* cla
 void SimpleCodeGenerator::writeCodeToFile()
 {
     m_fileMap.clear(); // need to do this, else just keep getting same directory to write to.
-    UMLClassifierList concepts = m_doc->getClassesAndInterfaces();
+    UMLClassifierList concepts = m_doc->classesAndInterfaces();
     foreach (UMLClassifier* c, concepts ) {
-        if (! Model_Utils::isCommonDataType(c->getName()))
+        if (! Model_Utils::isCommonDataType(c->name()))
             this->writeClass(c); // call the writer for each class.
     }
 }
@@ -313,7 +313,7 @@ void SimpleCodeGenerator::initFields(UMLDoc * parentDoc)
  */
 void SimpleCodeGenerator::syncCodeToDocument()
 {
-    CodeGenerationPolicy *policy = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *policy = UMLApp::app()->commonPolicy();
 
     m_indentation = policy->getIndentation();
     m_endl = policy->getNewLineEndingChars();
