@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *  copyright (C) 2005                                                     *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 #ifndef IDLIMPORT_H
@@ -24,26 +24,13 @@ public:
     IDLImport();
     virtual ~IDLImport();
 
-    /**
-     * Implement abstract operation from NativeImportBase.
-     */
     bool parseStmt();
 
-    /**
-     * Reimplement operation from NativeImportBase.
-     * Need to do this because we use the external C preprocessor.
-     */
-    void parseFile(QString file);
+    void parseFile(const QString& file);
 
-    /**
-     * Override operation from NativeImportBase.
-     */
     bool preprocess(QString& line);
 
-    /**
-     * Implement abstract operation from NativeImportBase.
-     */
-    void fillSource(QString word);
+    void fillSource(const QString& word);
 
 protected:
     QString joinTypename();
