@@ -137,7 +137,7 @@ void JavaImport::spawnImport(const QString& file )
  */
 UMLObject* JavaImport::findObject(const QString& name, UMLPackage *parentPkg)
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     UMLObject * o = umldoc->findUMLObject(name, Uml::ot_UMLObject , parentPkg);
     return o;
 }
@@ -465,7 +465,8 @@ bool JavaImport::parseStmt()
     // of an operation.) Up next is the name of the attribute
     // or operation.
     if (! keyword.contains( QRegExp("^\\w") )) {
-        uError() << "importJava: ignoring " << keyword;
+        uError() << "importJava: ignoring " << keyword <<
+            " at " << m_srcIndex << ", " << m_source.count() << " in " << m_klass->name();
         return false;
     }
     QString typeName = m_source[m_srcIndex];
@@ -477,7 +478,7 @@ bool JavaImport::parseStmt()
     }
     QString name = advance();
     QString nextToken;
-    if (typeName == m_klass->getName() && name == "(") {
+    if (typeName == m_klass->name() && name == "(") {
         // Constructor.
         nextToken = name;
         name = typeName;
@@ -505,7 +506,7 @@ bool JavaImport::parseStmt()
             UMLObject *obj = resolveClass(typeName);
             if (obj) {
                 // by prepending the package, unwanted placeholder types will not get created
-                typeName = obj->getFullyQualifiedName(".");
+                typeName = obj->fullyQualifiedName(".");
             }
             /* UMLAttribute *att = */ Import_Utils::addMethodParameter(op, typeName, parName);
             if (advance() != ",")
@@ -516,7 +517,7 @@ bool JavaImport::parseStmt()
         UMLObject *obj = resolveClass(typeName);
         if (obj) {
             // using the fully qualified name means that a placeholder type will not be created.
-            typeName = obj->getFullyQualifiedName(".");
+            typeName = obj->fullyQualifiedName(".");
         }
         Import_Utils::insertMethod(m_klass, op, m_currentAccess, typeName,
                                    m_isStatic, m_isAbstract, false /*isFriend*/,
@@ -561,7 +562,7 @@ bool JavaImport::parseStmt()
                 name += nextToken;  // add possible array dimensions to `name'
             }
             nextToken = advance();
-            if (nextToken == QString()) {
+            if (nextToken.isEmpty()) {
                 break;
             }
         }
@@ -586,8 +587,14 @@ bool JavaImport::parseStmt()
     }
     // reset visibility to default
     m_currentAccess = m_defaultCurrentAccess;
-    if (m_source[m_srcIndex] != ";") {
-        uError() << "importJava: ignoring trailing items at " << name;
+    if (m_srcIndex < m_source.count()) {
+        if (m_source[m_srcIndex] != ";") {
+            uError() << "importJava: ignoring trailing items at " << name;
+            skipStmt();
+        }
+    }
+    else {
+        uError() << "index out of range: ignoring statement " << name;
         skipStmt();
     }
     return true;
