@@ -23,7 +23,7 @@
 #include "position.h"
 #include <memory>
 #include <QtCore/QString>
-#include <q3ptrlist.h>
+#include <QtCore/QList>
 
 #if defined( Q_OS_WIN32 ) || defined( Q_CC_SUN )
 
@@ -41,7 +41,7 @@ public:
     explicit AUTO_PTR(_Tp* __p = 0)  _THROW0() : _M_ptr(__p) {}
 
     template <class _Tp1> AUTO_PTR(AUTO_PTR<_Tp1>& __a)  _THROW0()
-	: _M_ptr(__a.release()) {}
+      : _M_ptr(__a.release()) {}
 
     AUTO_PTR(AUTO_PTR& __a)  _THROW0() : _M_ptr(__a.release()) {}
 
@@ -206,7 +206,7 @@ public:
 
     DECLARE_ALLOC( AST )
 
-    public:
+public:
     AST();
     virtual ~AST();
 
@@ -216,30 +216,30 @@ public:
     AST* parent() { return m_parent; }
     void setParent( AST* parent );
 
-  void setStartPosition( Position const& p );
-  Position const& getStartPosition() const;
+    void setStartPosition( Position const& p );
+    Position const& getStartPosition() const;
 
-  void setEndPosition( Position const& p );
-  Position const& getEndPosition() const;
+    void setEndPosition( Position const& p );
+    Position const& getEndPosition() const;
 
 #ifndef CPPPARSER_NO_CHILDREN
-    Q3PtrList<AST> children() { return m_children; }
+    QList<AST*> children() { return m_children; }
     void appendChild( AST* child );
     void removeChild( AST* child );
 #endif
 
     virtual inline QString text() const
-  { return m_slice; }
+    { return m_slice; }
 
     QString comment() const
     { return m_comment; }
 
-  inline void setSlice( const QString& slice )
+    inline void setSlice( const QString& slice )
     { m_slice = slice; }
 
     inline void setSlice( const QString &text, int position, int length )
     {
-    m_slice = text.mid( position, length );
+        m_slice = text.mid( position, length );
     }
 
     inline void setText(const QString &text)
@@ -251,10 +251,10 @@ public:
 private:
     int m_nodeType;
     AST* m_parent;
-  Position m_startPosition, m_endPosition;
-  QString m_slice;
+    Position m_startPosition, m_endPosition;
+    QString m_slice;
 #ifndef CPPPARSER_NO_CHILDREN
-    Q3PtrList<AST> m_children;
+    QList<AST*> m_children;
 #endif
     QString m_comment;
 
@@ -274,13 +274,13 @@ public:
     public:
     GroupAST();
 
-    Q3PtrList<AST> nodeList() { return m_nodeList; }
+    QList<AST*> nodeList() { return m_nodeList; }
     void addNode( AST::Node& node );
 
     virtual QString text() const;
 
 private:
-    Q3PtrList<AST> m_nodeList;
+    QList<AST*> m_nodeList;
 
 private:
     GroupAST( const GroupAST& source );
@@ -300,12 +300,12 @@ public:
     TemplateArgumentListAST();
 
     void addArgument( AST::Node& arg );
-    Q3PtrList<AST> argumentList() { return m_argumentList; }
+    QList<AST*> argumentList() { return m_argumentList; }
 
     virtual QString text() const;
 
 private:
-    Q3PtrList<AST> m_argumentList;
+    QList<AST*> m_argumentList;
 
 private:
     TemplateArgumentListAST( const TemplateArgumentListAST& source );
@@ -355,7 +355,7 @@ public:
     void setGlobal( bool b );
 
     void addClassOrNamespaceName( ClassOrNamespaceNameAST::Node& classOrNamespaceName );
-    Q3PtrList<ClassOrNamespaceNameAST> classOrNamespaceNameList() { return m_classOrNamespaceNameList; }
+    QList<ClassOrNamespaceNameAST*> classOrNamespaceNameList() { return m_classOrNamespaceNameList; }
 
     ClassOrNamespaceNameAST* unqualifiedName() { return m_unqualifiedName.get(); }
     void setUnqualifiedName( ClassOrNamespaceNameAST::Node& unqualifiedName );
@@ -365,7 +365,7 @@ public:
 private:
     bool m_global;
     ClassOrNamespaceNameAST::Node m_unqualifiedName;
-    Q3PtrList<ClassOrNamespaceNameAST> m_classOrNamespaceNameList;
+    QList<ClassOrNamespaceNameAST*> m_classOrNamespaceNameList;
 
 private:
     NameAST( const NameAST& source );
@@ -433,13 +433,13 @@ public:
     public:
     AccessDeclarationAST();
 
-    Q3PtrList<AST> accessList() { return m_accessList; }
+    QList<AST*> accessList() { return m_accessList; }
     void addAccess( AST::Node& access );
 
     virtual QString text() const;
 
 private:
-    Q3PtrList<AST> m_accessList;
+    QList<AST*> m_accessList;
 
 private:
     AccessDeclarationAST( const AccessDeclarationAST& source );
@@ -520,10 +520,10 @@ public:
     BaseClauseAST();
 
     void addBaseSpecifier( BaseSpecifierAST::Node& baseSpecifier );
-    Q3PtrList<BaseSpecifierAST> baseSpecifierList() { return m_baseSpecifierList; }
+    QList<BaseSpecifierAST*> baseSpecifierList() { return m_baseSpecifierList; }
 
 private:
-    Q3PtrList<BaseSpecifierAST> m_baseSpecifierList;
+    QList<BaseSpecifierAST*> m_baseSpecifierList;
 
 private:
     BaseClauseAST( const BaseClauseAST& source );
@@ -550,14 +550,14 @@ public:
     BaseClauseAST* baseClause() { return m_baseClause.get(); }
     void setBaseClause( BaseClauseAST::Node& baseClause );
 
-    Q3PtrList<DeclarationAST> declarationList() { return m_declarationList; }
+    QList<DeclarationAST*> declarationList() { return m_declarationList; }
     void addDeclaration( DeclarationAST::Node& declaration );
 
 private:
     GroupAST::Node m_winDeclSpec;
     AST::Node m_classKey;
     BaseClauseAST::Node m_baseClause;
-    Q3PtrList<DeclarationAST> m_declarationList;
+    QList<DeclarationAST*> m_declarationList;
 
 private:
     ClassSpecifierAST( const ClassSpecifierAST& source );
@@ -602,10 +602,10 @@ public:
     EnumSpecifierAST();
 
     void addEnumerator( EnumeratorAST::Node& enumerator );
-    Q3PtrList<EnumeratorAST> enumeratorList() { return m_enumeratorList; }
+    QList<EnumeratorAST*> enumeratorList() { return m_enumeratorList; }
 
 private:
-    Q3PtrList<EnumeratorAST> m_enumeratorList;
+    QList<EnumeratorAST*> m_enumeratorList;
 
 private:
     EnumSpecifierAST( const EnumSpecifierAST& source );
@@ -636,7 +636,6 @@ private:
     void operator = ( const ElaboratedTypeSpecifierAST& source );
 };
 
-
 class LinkageBodyAST: public AST
 {
 public:
@@ -649,10 +648,10 @@ public:
     LinkageBodyAST();
 
     void addDeclaration( DeclarationAST::Node& ast );
-    Q3PtrList<DeclarationAST> declarationList() { return m_declarationList; }
+    QList<DeclarationAST*> declarationList() { return m_declarationList; }
 
 private:
-    Q3PtrList<DeclarationAST> m_declarationList;
+    QList<DeclarationAST*> m_declarationList;
 
 private:
     LinkageBodyAST( const LinkageBodyAST& source );
@@ -800,7 +799,7 @@ public:
     public:
     DeclaratorAST();
 
-    Q3PtrList<AST> ptrOpList() { return m_ptrOpList; }
+    QList<AST*> ptrOpList() { return m_ptrOpList; }
     void addPtrOp( AST::Node& ptrOp );
 
     DeclaratorAST* subDeclarator() { return m_subDeclarator.get(); }
@@ -812,7 +811,7 @@ public:
     AST* bitfieldInitialization() { return m_bitfieldInitialization.get(); }
     void setBitfieldInitialization( AST::Node& bitfieldInitialization );
 
-    Q3PtrList<AST> arrayDimensionList() { return m_arrayDimensionList; }
+    QList<AST*> arrayDimensionList() { return m_arrayDimensionList; }
     void addArrayDimension( AST::Node& arrayDimension );
 
     class ParameterDeclarationClauseAST* parameterDeclarationClause() { return m_parameterDeclarationClause.get(); }
@@ -826,11 +825,11 @@ public:
     void setExceptionSpecification( GroupAST::Node& exceptionSpecification );
 
 private:
-    Q3PtrList<AST> m_ptrOpList;
+    QList<AST*> m_ptrOpList;
     Node m_subDeclarator;
     NameAST::Node m_declaratorId;
     AST::Node m_bitfieldInitialization;
-    Q3PtrList<AST> m_arrayDimensionList;
+    QList<AST*> m_arrayDimensionList;
     AUTO_PTR<class ParameterDeclarationClauseAST> m_parameterDeclarationClause;
     AST::Node m_constant;
     GroupAST::Node m_exceptionSpecification;
@@ -883,13 +882,13 @@ public:
     public:
     ParameterDeclarationListAST();
 
-    Q3PtrList<ParameterDeclarationAST> parameterList() { return m_parameterList; }
+    QList<ParameterDeclarationAST*> parameterList() { return m_parameterList; }
     void addParameter( ParameterDeclarationAST::Node& parameter );
 
     virtual QString text() const;
 
 private:
-    Q3PtrList<ParameterDeclarationAST> m_parameterList;
+    QList<ParameterDeclarationAST*> m_parameterList;
 
 private:
     ParameterDeclarationListAST( const ParameterDeclarationListAST& source );
@@ -962,11 +961,11 @@ public:
     public:
     InitDeclaratorListAST();
 
-    Q3PtrList<InitDeclaratorAST> initDeclaratorList() { return m_initDeclaratorList; }
+    QList<InitDeclaratorAST*> initDeclaratorList() { return m_initDeclaratorList; }
     void addInitDeclarator( InitDeclaratorAST::Node& decl );
 
 private:
-    Q3PtrList<InitDeclaratorAST> m_initDeclaratorList;
+    QList<InitDeclaratorAST*> m_initDeclaratorList;
 
 private:
     InitDeclaratorListAST( const InitDeclaratorListAST& source );
@@ -1036,11 +1035,11 @@ public:
     public:
     TemplateParameterListAST();
 
-    Q3PtrList<TemplateParameterAST> templateParameterList() { return m_templateParameterList; }
+    QList<TemplateParameterAST*> templateParameterList() { return m_templateParameterList; }
     void addTemplateParameter( TemplateParameterAST::Node& templateParameter );
 
 private:
-    Q3PtrList<TemplateParameterAST> m_templateParameterList;
+    QList<TemplateParameterAST*> m_templateParameterList;
 
 private:
     TemplateParameterListAST( const TemplateParameterListAST& source );
@@ -1336,11 +1335,11 @@ public:
     public:
     StatementListAST();
 
-    Q3PtrList<StatementAST> statementList() { return m_statementList; }
+    QList<StatementAST*> statementList() { return m_statementList; }
     void addStatement( StatementAST::Node& statement );
 
 private:
-    Q3PtrList<StatementAST> m_statementList;
+    QList<StatementAST*> m_statementList;
 
 private:
     StatementListAST( const StatementListAST& source );
@@ -1424,10 +1423,10 @@ public:
     TranslationUnitAST();
 
     void addDeclaration( DeclarationAST::Node& ast );
-    Q3PtrList<DeclarationAST> declarationList() { return m_declarationList; }
+    QList<DeclarationAST*> declarationList() { return m_declarationList; }
 
 private:
-    Q3PtrList<DeclarationAST> m_declarationList;
+    QList<DeclarationAST*> m_declarationList;
 
 private:
     TranslationUnitAST( const TranslationUnitAST& source );
