@@ -6,33 +6,36 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2007                                               *
+ *   copyright (C) 2004-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "cpptree2uml.h"
-// qt/kde includes
-#include <qfileinfo.h>
-#include <qdir.h>
-#include <qregexp.h>
-//Added by qt3to4:
-#include <Q3PtrList>
-#include <kdebug.h>
+
 // app includes
 #include "ast_utils.h"
-#include "urlutil.h"
-#include "../import_utils.h"
+#include "import_utils.h"
 // FIXME: The sole reason for the next 2 includes is parseTypedef().
 // Make capsule methods in ClassImport, and remove these includes.
-#include "../../classifier.h"
+#include "classifier.h"
 // FIXME The next include is motivated by template params
-#include "../../template.h"
+#include "template.h"
+
+// kde includes
+#include <kdebug.h>
+
+// qt includes
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
+#include <QtCore/QRegExp>
+#include <QtCore/QList>
 
 CppTree2Uml::CppTree2Uml( const QString& fileName)
     : m_anon( 0 ), m_nsCnt( 0 ), m_clsCnt( 0 )
 {
-    m_fileName = URLUtil::canonicalPath(fileName);
+    QDir dir(fileName);
+    m_fileName = dir.canonicalPath();
 }
 
 CppTree2Uml::~CppTree2Uml()
@@ -61,8 +64,7 @@ void CppTree2Uml::parseTranslationUnit( TranslationUnitAST* ast )
 void CppTree2Uml::parseNamespace( NamespaceAST* ast )
 {
     if (m_clsCnt > 0) {
-        kDebug() << "CppTree2Uml::parseNamespace: error - cannot nest namespace inside class"
-                  << endl;
+        uDebug() << "error - cannot nest namespace inside class";
         return;
     }
 
@@ -77,7 +79,7 @@ void CppTree2Uml::parseNamespace( NamespaceAST* ast )
     }
 
 #ifdef DEBUG_CPPTREE2UML
-    kDebug() << "CppTree2Uml::parseNamespace: " << nsName;
+    uDebug() << nsName;
 #endif
     UMLObject * o = Import_Utils::createUMLObject( Uml::ot_Package, nsName,
                                                  m_currentNamespace[m_nsCnt],
@@ -85,7 +87,7 @@ void CppTree2Uml::parseNamespace( NamespaceAST* ast )
     UMLPackage *ns = (UMLPackage *)o;
     m_currentScope.push_back( nsName );
     if (++m_nsCnt > STACKSIZE) {
-        kError() << "CppTree2Uml::parseNamespace: excessive namespace nesting" << endl;
+        uError() << "excessive namespace nesting";
         m_nsCnt = STACKSIZE;
     }
     m_currentNamespace[m_nsCnt] = ns;
@@ -98,21 +100,6 @@ void CppTree2Uml::parseNamespace( NamespaceAST* ast )
 
 void CppTree2Uml::parseTypedef( TypedefAST* ast )
 {
-#if 0
-    DeclaratorAST* oldDeclarator = m_currentDeclarator;
-
-    if( ast && ast->initDeclaratorList() && ast->initDeclaratorList()->initDeclaratorList().count() > 0 ) {
-            Q3PtrList<InitDeclaratorAST> lst( ast->initDeclaratorList()->initDeclaratorList() );
-            m_currentDeclarator = lst.at( 0 )->declarator();
-    }
-
-    m_inTypedef = true;
-
-    TreeParser::parseTypedef( ast );
-
-    m_inTypedef = false;
-    m_currentDeclarator = oldDeclarator;
-#else
     TypeSpecifierAST* typeSpec = ast->typeSpec();
     InitDeclaratorListAST* declarators = ast->initDeclaratorList();
 
@@ -122,12 +109,11 @@ void CppTree2Uml::parseTypedef( TypedefAST* ast )
         if( typeSpec->name() )
             typeId = typeSpec->name()->text();
 
-        Q3PtrList<InitDeclaratorAST> l( declarators->initDeclaratorList() );
-        Q3PtrListIterator<InitDeclaratorAST> it( l );
-
+        QList<InitDeclaratorAST*> l( declarators->initDeclaratorList() );
         InitDeclaratorAST* initDecl = 0;
-        while( 0 != (initDecl = it.current()) ){
-
+        for( int i = 0; i < l.size(); ++i ) {
+            initDecl = l.at(i);
+            if (initDecl==0) break;
             QString type, id;
             if( initDecl->declarator() ){
                type = typeOfDeclaration( typeSpec, initDecl->declarator() );
@@ -140,9 +126,6 @@ void CppTree2Uml::parseTypedef( TypedefAST* ast )
                if( d->declaratorId() )
                   id = d->declaratorId()->text();
             }
-//#ifdef DEBUG_CPPTREE2UML
-            kDebug() << "CppTree2Uml::parseTypedef: name=" << id << ", type=" << type;
-//#endif
             /* @todo Trace typedefs back to their root type for deciding
                      whether to build a Datatype (for pointers.)  */
             /* check out if the ID type is a Datatype
@@ -168,11 +151,9 @@ void CppTree2Uml::parseTypedef( TypedefAST* ast )
                                              "" /* doc */,
                                              "typedef" /* stereotype */);
             }
-            ++it;
         }
 
     }
-#endif
 }
 
 void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
@@ -180,11 +161,10 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
     TemplateParameterListAST* parmListAST = ast->templateParameterList();
     if (parmListAST == NULL)
         return;
-    Q3PtrList<TemplateParameterAST> parmList = parmListAST->templateParameterList();
-    for (Q3PtrListIterator<TemplateParameterAST> it(parmList); it.current(); ++it) {
+    QList<TemplateParameterAST*> parmList = parmListAST->templateParameterList();
+    for( int i = 0; i < parmList.size(); ++i ) {
         // The template is either a typeParameter or a typeValueParameter.
-
-        TemplateParameterAST* tmplParmNode = it.current();
+        TemplateParameterAST* tmplParmNode = parmList.at(i);
         TypeParameterAST* typeParmNode = tmplParmNode->typeParameter();
         if (typeParmNode) {
             NameAST* nameNode = typeParmNode->name();
@@ -193,8 +173,7 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
                 Model_Utils::NameAndType nt(typeName, NULL);
                 m_templateParams.append(nt);
             } else {
-                kError() << "CppTree2Uml::parseTemplateDeclaration(type):"
-                          << " nameNode is NULL" << endl;
+                uError() << "nameNode is NULL";
             }
         }
 
@@ -202,8 +181,7 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
         if (valueNode) {
             TypeSpecifierAST* typeSpec = valueNode->typeSpec();
             if (typeSpec == NULL) {
-                kError() << "CppTree2Uml::parseTemplateDeclaration(value):"
-                          << " typeSpec is NULL" << endl;
+                uError() << "typeSpec is NULL";
                 continue;
             }
             QString typeName = typeSpec->name()->text();
@@ -212,8 +190,8 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
             DeclaratorAST* declNode = valueNode->declarator();
             NameAST* nameNode = declNode->declaratorId();
             if (nameNode == NULL) {
-                kError() << "CppTree2Uml::parseTemplateDeclaration(value):"
-                          << " nameNode is NULL" << endl;
+                uError() << "CppTree2Uml::parseTemplateDeclaration(value):"
+                          << " nameNode is NULL";
                 continue;
             }
             QString paramName = nameNode->unqualifiedName()->text();
@@ -237,12 +215,9 @@ void CppTree2Uml::parseSimpleDeclaration( SimpleDeclarationAST* ast )
         parseTypeSpecifier( typeSpec );
 
     if( declarators ){
-        Q3PtrList<InitDeclaratorAST> l = declarators->initDeclaratorList();
-
-        Q3PtrListIterator<InitDeclaratorAST> it( l );
-        while( it.current() ){
-            parseDeclaration(  ast->functionSpecifier(), ast->storageSpecifier(), typeSpec, it.current() );
-            ++it;
+        QList<InitDeclaratorAST*> l = declarators->initDeclaratorList();
+        for( int i = 0; i < l.size(); ++i) {
+            parseDeclaration2(  ast->functionSpecifier(), ast->storageSpecifier(), typeSpec, l.at(i) );
         }
     }
 }
@@ -268,24 +243,20 @@ void CppTree2Uml::parseFunctionDefinition( FunctionDefinitionAST* ast )
     bool isConstructor = false;
 
     if( funSpec ){
-        Q3PtrList<AST> l = funSpec->nodeList();
-        Q3PtrListIterator<AST> it( l );
-        while( it.current() ){
-            QString text = it.current()->text();
+        QList<AST*> l = funSpec->nodeList();
+        for( int i = 0; i < l.size(); ++i ) {
+            QString text = l.at(i)->text();
             if( text == "virtual" ) isVirtual = true;
             else if( text == "inline" ) isInline = true;
-            ++it;
         }
     }
 
     if( storageSpec ){
-        Q3PtrList<AST> l = storageSpec->nodeList();
-        Q3PtrListIterator<AST> it( l );
-        while( it.current() ){
-            QString text = it.current()->text();
+        QList<AST*> l = storageSpec->nodeList();
+        for( int i = 0; i < l.size(); ++i ) {
+            QString text = l.at(i)->text();
             if( text == "friend" ) isFriend = true;
             else if( text == "static" ) isStatic = true;
-            ++it;
         }
     }
 
@@ -293,8 +264,7 @@ void CppTree2Uml::parseFunctionDefinition( FunctionDefinitionAST* ast )
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == NULL) {
-        kDebug() << "CppTree2Uml::parseFunctionDefinition (" << id
-                  << "): need a surrounding class." << endl;
+        uDebug() << id << ": need a surrounding class.";
         return;
     }
 
@@ -340,11 +310,9 @@ void CppTree2Uml::parseClassSpecifier( ClassSpecifierAST* ast )
     } else {
         className = ast->name()->unqualifiedName()->text().trimmed();
     }
-//#ifdef DEBUG_CPPTREE2UML
-    kDebug() << "CppTree2Uml::parseClassSpecifier: name=" << className;
-//#endif
+    uDebug() << "name=" << className;
     if( !scopeOfName( ast->name(), QStringList() ).isEmpty() ){
-        kDebug() << "skip private class declarations";
+        uDebug() << "skip private class declarations";
         return;
     }
 
@@ -362,12 +330,12 @@ void CppTree2Uml::parseClassSpecifier( ClassSpecifierAST* ast )
 
     m_currentScope.push_back( className );
     if (++m_clsCnt > STACKSIZE) {
-        kError() << "CppTree2Uml::parseNamespace: excessive class nesting" << endl;
+        uError() << "excessive class nesting";
         m_clsCnt = STACKSIZE;
     }
     m_currentClass[m_clsCnt] = klass;
     if (++m_nsCnt > STACKSIZE) {
-        kError() << "CppTree2Uml::parseNamespace: excessive namespace nesting" << endl;
+        uError() << "excessive namespace nesting";
         m_nsCnt = STACKSIZE;
     }
     m_currentNamespace[m_nsCnt] = (UMLPackage*)klass;
@@ -396,12 +364,10 @@ void CppTree2Uml::parseEnumSpecifier( EnumSpecifierAST* ast )
                                                 m_currentNamespace[m_nsCnt],
                                                 ast->comment() );
 
-    Q3PtrList<EnumeratorAST> l = ast->enumeratorList();
-    Q3PtrListIterator<EnumeratorAST> it( l );
-    while ( it.current() ) {
-        QString enumLiteral = it.current()->id()->text();
+    QList<EnumeratorAST*> l = ast->enumeratorList();
+    for( int i = 0; i < l.size(); ++i ) {
+        QString enumLiteral = l.at(i)->id()->text();
         Import_Utils::addEnumLiteral( (UMLEnum*)o, enumLiteral );
-        ++it;
     }
 }
 
@@ -412,13 +378,13 @@ void CppTree2Uml::parseElaboratedTypeSpecifier( ElaboratedTypeSpecifierAST* type
     ///              - Using typeSpec->text() is probably not good, decode
     ///                the kind() instead.
     QString text = typeSpec->text();
-    kDebug() << "CppTree2Uml::parseElaboratedTypeSpecifier: text is " << text;
+    uDebug() << "text is " << text;
     text.remove(QRegExp("^class\\s+"));
     UMLObject *o = Import_Utils::createUMLObject(Uml::ot_Class, text, m_currentNamespace[m_nsCnt]);
     flushTemplateParams( static_cast<UMLClassifier*>(o) );
 }
 
-void CppTree2Uml::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
+void CppTree2Uml::parseDeclaration2( GroupAST* funSpec, GroupAST* storageSpec,
                                     TypeSpecifierAST* typeSpec, InitDeclaratorAST* decl )
 {
     if( m_inStorageSpec )
@@ -441,15 +407,13 @@ void CppTree2Uml::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
         id = t->declaratorId()->unqualifiedName()->text();
 
     if( !scopeOfDeclarator(d, QStringList()).isEmpty() ){
-        kDebug() << "CppTree2Uml::parseDeclaration (" << id << "): skipping."
-                  << endl;
+        uDebug() << id << ": skipping.";
         return;
     }
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == NULL) {
-        kDebug() << "CppTree2Uml::parseDeclaration (" << id
-                  << "): need a surrounding class." << endl;
+        uDebug() << id << ": need a surrounding class.";
         return;
     }
 
@@ -459,13 +423,11 @@ void CppTree2Uml::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
     //bool isInitialized = decl->initializer() != 0;
 
     if( storageSpec ){
-        Q3PtrList<AST> l = storageSpec->nodeList();
-        Q3PtrListIterator<AST> it( l );
-        while( it.current() ){
-            QString text = it.current()->text();
+        QList<AST*> l = storageSpec->nodeList();
+        for( int i = 0; i < l.size(); ++i ) {
+            QString text = l.at(i)->text();
             if( text == "friend" ) isFriend = true;
             else if( text == "static" ) isStatic = true;
-            ++it;
         }
     }
 
@@ -476,7 +438,7 @@ void CppTree2Uml::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
 
 void CppTree2Uml::parseAccessDeclaration( AccessDeclarationAST * access )
 {
-    Q3PtrList<AST> l = access->accessList();
+    QList<AST*> l = access->accessList();
 
     QString accessStr = l.at( 0 )->text();
 
@@ -497,24 +459,20 @@ void CppTree2Uml::parseFunctionDeclaration(  GroupAST* funSpec, GroupAST* storag
     bool isConstructor = false;
 
     if( funSpec ){
-        Q3PtrList<AST> l = funSpec->nodeList();
-        Q3PtrListIterator<AST> it( l );
-        while( it.current() ){
-            QString text = it.current()->text();
+        QList<AST*> l = funSpec->nodeList();
+        for( int i = 0; i < l.size(); ++i ) {
+            QString text = l.at(i)->text();
             if( text == "virtual" ) isVirtual = true;
             else if( text == "inline" ) isInline = true;
-            ++it;
         }
     }
 
     if( storageSpec ){
-        Q3PtrList<AST> l = storageSpec->nodeList();
-        Q3PtrListIterator<AST> it( l );
-        while( it.current() ){
-            QString text = it.current()->text();
+        QList<AST*> l = storageSpec->nodeList();
+        for( int i = 0; i < l.size(); ++i ) {
+            QString text = l.at(i)->text();
             if( text == "friend" ) isFriend = true;
             else if( text == "static" ) isStatic = true;
-            ++it;
         }
     }
 
@@ -523,8 +481,7 @@ void CppTree2Uml::parseFunctionDeclaration(  GroupAST* funSpec, GroupAST* storag
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == NULL) {
-        kDebug() << "CppTree2Uml::parseFunctionDeclaration (" << id
-                  << "): need a surrounding class." << endl;
+        uDebug() << id << ": need a surrounding class.";
         return;
     }
 
@@ -548,11 +505,9 @@ void CppTree2Uml::parseFunctionArguments(DeclaratorAST* declarator,
 
     if( clause && clause->parameterDeclarationList() ){
         ParameterDeclarationListAST* params = clause->parameterDeclarationList();
-        Q3PtrList<ParameterDeclarationAST> l( params->parameterList() );
-        Q3PtrListIterator<ParameterDeclarationAST> it( l );
-        while( it.current() ){
-            ParameterDeclarationAST* param = it.current();
-            ++it;
+        QList<ParameterDeclarationAST*> l( params->parameterList() );
+        for( int i = 0; i < l.size(); ++i) {
+            ParameterDeclarationAST* param = l.at(i);
 
             QString name;
             if (param->declarator())
@@ -575,9 +530,9 @@ QString CppTree2Uml::typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAS
 
     text += typeSpec->text();
 
-    Q3PtrList<AST> ptrOpList = declarator->ptrOpList();
-    for( Q3PtrListIterator<AST> it(ptrOpList); it.current(); ++it ){
-        text += it.current()->text();
+    QList<AST*> ptrOpList = declarator->ptrOpList();
+    for( int i = 0; i < ptrOpList.size(); ++i ) {
+        text += ptrOpList.at(i)->text();
     }
 
     return text;
@@ -585,15 +540,12 @@ QString CppTree2Uml::typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAS
 
 void CppTree2Uml::parseBaseClause( BaseClauseAST * baseClause, UMLClassifier* klass )
 {
-    Q3PtrList<BaseSpecifierAST> l = baseClause->baseSpecifierList();
-    Q3PtrListIterator<BaseSpecifierAST> it( l );
-    while( it.current() ){
-        BaseSpecifierAST* baseSpecifier = it.current();
-        ++it;
+    QList<BaseSpecifierAST*> l = baseClause->baseSpecifierList();
+    for( int i = 0; i < l.size(); ++i ) {
+        BaseSpecifierAST* baseSpecifier = l.at(i);
 
         if (baseSpecifier->name() == NULL) {
-                kDebug() << "CppTree2Uml::parseBaseClause: baseSpecifier->name() is NULL"
-                          << endl;
+                uDebug() << "baseSpecifier->name() is NULL";
                 continue;
         }
 
@@ -608,13 +560,11 @@ QStringList CppTree2Uml::scopeOfName( NameAST* id, const QStringList& startScope
     if( id && id->classOrNamespaceNameList().count() ){
         if( id->isGlobal() )
             scope.clear();
-        Q3PtrList<ClassOrNamespaceNameAST> l = id->classOrNamespaceNameList();
-        Q3PtrListIterator<ClassOrNamespaceNameAST> it( l );
-        while( it.current() ){
-            if( it.current()->name() ){
-               scope << it.current()->name()->text();
+        QList<ClassOrNamespaceNameAST*> l = id->classOrNamespaceNameList();
+        for( int i = 0; i < l.size(); ++i ) {
+            if( l.at(i)->name() ){
+               scope << l.at(i)->name()->text();
             }
-            ++it;
         }
     }
 
@@ -626,13 +576,16 @@ QStringList CppTree2Uml::scopeOfDeclarator( DeclaratorAST* d, const QStringList&
     return scopeOfName( d->declaratorId(), startScope );
 }
 
-void CppTree2Uml::flushTemplateParams(UMLClassifier *klass) {
+/**
+ * Flush template parameters pending in m_templateParams to the klass.
+ */
+void CppTree2Uml::flushTemplateParams(UMLClassifier *klass)
+{
     if (m_templateParams.count()) {
         Model_Utils::NameAndType_ListIt it;
         for (it = m_templateParams.begin(); it != m_templateParams.end(); ++it) {
             const Model_Utils::NameAndType &nt = *it;
-            kDebug() << "CppTree2Uml::parseClassSpecifier: adding template param: "
-                      << nt.m_name << endl;
+            uDebug() << "adding template param: " << nt.m_name;
             UMLTemplate *tmpl = klass->addTemplate(nt.m_name);
             tmpl->setType(nt.m_type);
         }
