@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -35,6 +35,12 @@
 #include <QtGui/QComboBox>
 #include <QtGui/QRadioButton>
 
+/**
+ * Constructs a ParmPropDlg.
+ * @param parent   the parent of the dialog
+ * @param doc      
+ * @param attr     the parameter to represent
+ */
 ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * attr)
         : KDialog(parent)
 {
@@ -49,9 +55,9 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * attr)
     QString type, text, name, initialValue;
     if (attr) {
         type = attr->getTypeName();
-        name = attr->getName();
+        name = attr->name();
         initialValue = attr->getInitialValue();
-        text = attr->getDoc();
+        text = attr->doc();
     }
     int margin = fontMetrics().height();
     setMinimumSize(300, 400);
@@ -141,7 +147,7 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * attr)
     m_pStereoTypeCB->setDuplicatesEnabled(false); //only allow one of each type in box
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
     if (m_pAtt) {
-        insertStereotypesSorted(m_pAtt->getStereotype());
+        insertStereotypesSorted(m_pAtt->stereotype());
     }
 
     // set tab order
@@ -155,28 +161,37 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * attr)
     m_pNameLE->setFocus();
 }
 
+/**
+ * Standard destructor.
+ */
 ParmPropDlg::~ParmPropDlg()
 {
 }
 
+/**
+ * Inserts @p type into the type-combobox as well as its completion object.
+ * The combobox is cleared and all types together with the optional new one
+ * sorted and then added again.
+ * @param type   a new type to add and selected
+ */
 void ParmPropDlg::insertTypesSorted(const QString& type)
 {
     QStringList types;
     // add template parameters
     UMLClassifier *pConcept = dynamic_cast<UMLClassifier*>( m_pAtt->parent()->parent() );
     if (pConcept == NULL) {
-        uError() << "ParmPropDlg: grandparent of " << m_pAtt->getName()
+        uError() << "ParmPropDlg: grandparent of " << m_pAtt->name()
                  << " is not a UMLClassifier";
     } else {
         UMLTemplateList tmplParams( pConcept->getTemplateList() );
         foreach( UMLTemplate* t, tmplParams ) {
-            types << t->getName();
+            types << t->name();
         }
     }
     // now add the Concepts
-    UMLClassifierList namesList( m_pUmldoc->getConcepts() );
+    UMLClassifierList namesList( m_pUmldoc->concepts() );
     foreach(UMLClassifier* obj, namesList ) {
-        types << obj->getFullyQualifiedName();
+        types << obj->fullyQualifiedName();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
@@ -194,12 +209,18 @@ void ParmPropDlg::insertTypesSorted(const QString& type)
     }
 }
 
+/**
+ * Inserts @p type into the stereotype-combobox as well as its completion object.
+ * The combobox is cleared and all types together with the optional new one
+ * sorted and then added again.
+ * @param type   a new type to add and selected
+ */
 void ParmPropDlg::insertStereotypesSorted(const QString& type)
 {
     QStringList types;
     types << ""; // an empty stereotype is the default
-    foreach (UMLStereotype* currentSt, m_pUmldoc->getStereotypes() ) {
-        types << currentSt->getName();
+    foreach (UMLStereotype* currentSt, m_pUmldoc->stereotypes() ) {
+        types << currentSt->name();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
@@ -217,6 +238,11 @@ void ParmPropDlg::insertStereotypesSorted(const QString& type)
     }
 }
 
+/**
+ * Return the kind of the parameter (in, out, or inout).
+ * @return  The Uml::Parameter_Direction corresponding to
+ *          the selected "Kind" radiobutton.
+ */
 Uml::Parameter_Direction ParmPropDlg::getParmKind()
 {
     Uml::Parameter_Direction pk = Uml::pd_In;
@@ -227,6 +253,10 @@ Uml::Parameter_Direction ParmPropDlg::getParmKind()
     return pk;
 }
 
+/**
+ * Validates the fields in the dialog box.
+ * @return success state
+ */
 bool ParmPropDlg::validate()
 {
     // currently only validates whether the name is not null.
@@ -238,6 +268,10 @@ bool ParmPropDlg::validate()
     return true;
 }
 
+/**
+ * Activated when a button is clicked
+ * @param button The button that was clicked
+ */
 void ParmPropDlg::slotButtonClicked(int button)
 {
     if ( button == KDialog::Ok ) {
@@ -248,6 +282,9 @@ void ParmPropDlg::slotButtonClicked(int button)
     KDialog::slotButtonClicked( button );
 }
 
+/**
+ * Ok clicked slot.
+ */
 void ParmPropDlg::slotOk()
 {
     if (m_pAtt != NULL) {
@@ -260,7 +297,7 @@ void ParmPropDlg::slotOk()
         QString typeName = m_pTypeCB->currentText();
         UMLClassifier * pConcept = dynamic_cast<UMLClassifier*>( m_pAtt->parent()->parent() );
         if (pConcept == NULL) {
-            uError() << "grandparent of " << m_pAtt->getName() << " is not a UMLClassifier";
+            uError() << "grandparent of " << m_pAtt->name() << " is not a UMLClassifier";
         } else {
             UMLTemplate *tmplParam = pConcept->findTemplate(typeName);
             if (tmplParam) {
@@ -268,11 +305,11 @@ void ParmPropDlg::slotOk()
                 return;
             }
         }
-        UMLClassifierList namesList( m_pUmldoc->getConcepts() );
+        UMLClassifierList namesList( m_pUmldoc->concepts() );
         bool matchFound = false;
 
         foreach (UMLClassifier* obj, namesList) {
-            if (obj->getFullyQualifiedName() == typeName) {
+            if (obj->fullyQualifiedName() == typeName) {
                 m_pAtt->setType(obj);
                 matchFound = true;
                 break;
