@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -33,7 +33,6 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdialogbuttonbox.h>
-#include <karrowbutton.h>
 
 //qt includes
 #include <QtCore/QPointer>
@@ -47,7 +46,11 @@
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QGridLayout>
+#include <QtGui/QToolButton>
 
+/**
+ * Constructor.
+ */
 UMLOperationDialog::UMLOperationDialog( QWidget * parent, UMLOperation * pOperation )
   : KDialog( parent)
 {
@@ -58,13 +61,16 @@ UMLOperationDialog::UMLOperationDialog( QWidget * parent, UMLOperation * pOperat
     showButtonSeparator( true );
 
     m_operation = pOperation;
-    m_doc = UMLApp::app()->getDocument();
+    m_doc = UMLApp::app()->document();
     m_menu = 0;
     setupDialog();
     connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
 }
 
+/**
+ * Destructor.
+ */
 UMLOperationDialog::~UMLOperationDialog()
 {
 }
@@ -90,7 +96,7 @@ void UMLOperationDialog::setupDialog()
 
     Dialog_Utils::makeLabeledEditField( m_pGenGB, genLayout, 0,
                                     m_pNameL, i18nc("operation name", "&Name:"),
-                                    m_pNameLE, m_operation->getName() );
+                                    m_pNameLE, m_operation->name() );
 
     m_pRtypeL = new QLabel(i18n("&Type:"), m_pGenGB );
     genLayout->addWidget(m_pRtypeL, 0, 2);
@@ -105,10 +111,10 @@ void UMLOperationDialog::setupDialog()
     genLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
     m_pAbstractCB = new QCheckBox( i18n("&Abstract operation"), m_pGenGB );
-    m_pAbstractCB->setChecked( m_operation->getAbstract() );
+    m_pAbstractCB->setChecked( m_operation->isAbstract() );
     genLayout->addWidget( m_pAbstractCB, 2, 0 );
     m_pStaticCB = new QCheckBox( i18n("Classifier &scope (\"static\")"), m_pGenGB );
-    m_pStaticCB->setChecked( m_operation->getStatic() );
+    m_pStaticCB->setChecked( m_operation->isStatic() );
     genLayout->addWidget( m_pStaticCB, 2, 1 );
     m_pQueryCB = new QCheckBox( i18n("&Query (\"const\")"), m_pGenGB );
     m_pQueryCB->setChecked( m_operation->getConst() );
@@ -143,13 +149,16 @@ void UMLOperationDialog::setupDialog()
 
     // the move up/down buttons (another vertical box)
     QVBoxLayout* buttonLayout = new QVBoxLayout();
-    m_pUpButton = new KArrowButton( m_pParmsGB );
-    m_pUpButton->setEnabled( false );
-    buttonLayout->addWidget( m_pUpButton );
 
-    m_pDownButton = new KArrowButton( m_pParmsGB, Qt::DownArrow );
-    m_pDownButton->setEnabled( false );
-    buttonLayout->addWidget( m_pDownButton );
+    m_pUpButton = new QToolButton(m_pParmsGB);
+    m_pUpButton->setArrowType(Qt::UpArrow);
+    m_pUpButton->setEnabled(false);
+    buttonLayout->addWidget(m_pUpButton);
+
+    m_pDownButton = new QToolButton(m_pParmsGB);
+    m_pDownButton->setArrowType(Qt::DownArrow);
+    m_pDownButton->setEnabled(false);
+    buttonLayout->addWidget(m_pDownButton);
 
     KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pParmsGB);
     buttonBox->addButton( i18n("Ne&w Parameter..."), KDialogButtonBox::ActionRole,
@@ -186,7 +195,7 @@ void UMLOperationDialog::setupDialog()
     }
 
     // set scope
-    switch (m_operation->getVisibility()) {
+    switch (m_operation->visibility()) {
     case Uml::Visibility::Public:
         m_pPublicRB->setChecked( true );
         break;
@@ -206,7 +215,7 @@ void UMLOperationDialog::setupDialog()
     // manage stereotypes
     m_pStereoTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    insertStereotypesSorted(m_operation->getStereotype());
+    insertStereotypesSorted(m_operation->stereotype());
 
     // setup parm list box signals
     connect(m_pUpButton, SIGNAL( clicked() ), this, SLOT( slotParameterUp() ) );
@@ -285,7 +294,7 @@ void UMLOperationDialog::slotNewParameter()
 
     QPointer<ParmPropDlg> dlg = new ParmPropDlg(this, m_doc, newAttribute);
     if ( dlg->exec() ) {
-        pAtt = m_operation->findParm( newAttribute->getName() );
+        pAtt = m_operation->findParm( newAttribute->name() );
 
         if ( !pAtt ) {
             newAttribute->setID( UniqueID::gen() );
@@ -328,14 +337,14 @@ void UMLOperationDialog::slotParameterProperties()
         return;
     } // should never occur
 
-    QString oldAttName = pOldAtt->getName();
+    QString oldAttName = pOldAtt->name();
     UMLAttribute* tempAttribute = static_cast<UMLAttribute*>( pOldAtt->clone() ); // create a clone of the parameter
 
     // send the clone to the properties dialog box. it will fill in the new parameters.
     QPointer<ParmPropDlg> dlg = new ParmPropDlg(this, m_doc, tempAttribute); 
     if ( dlg->exec() ) {
         bool namingConflict = false;
-        QString newName = tempAttribute->getName();
+        QString newName = tempAttribute->name();
 
         pAtt = m_operation->findParm( newName ); // search whether a parameter with this name already exists
         if( pAtt && pAtt != pOldAtt  ) {
@@ -426,7 +435,7 @@ bool UMLOperationDialog::apply()
     if( name.length() == 0 ) {
         KMessageBox::error(this, i18n("You have entered an invalid operation name."),
                            i18n("Operation Name Invalid"), false);
-        m_pNameLE->setText( m_operation->getName() );
+        m_pNameLE->setText( m_operation->name() );
         return false;
     }
 
@@ -434,7 +443,7 @@ bool UMLOperationDialog::apply()
     if( classifier != 0 &&
             classifier->checkOperationSignature(name, m_operation->getParmList(), m_operation) )
     {
-        QString msg = i18n("An operation with that signature already exists in %1.\n", classifier->getName())
+        QString msg = i18n("An operation with that signature already exists in %1.\n", classifier->name())
                       +
                       i18n("Choose a different name or parameter list.");
         KMessageBox::error(this, msg, i18n("Operation Name Invalid"), false);
@@ -517,13 +526,13 @@ void UMLOperationDialog::insertTypesSorted( const QString& type )
     if (classifier) {
         UMLClassifierListItemList tmplParams( classifier->getFilteredList(Uml::ot_Template) );
         foreach (UMLClassifierListItem* li, tmplParams ) {
-            types << li->getName();
+            types << li->name();
         }
     }
     // add the Classes and Interfaces (both are Concepts)
-    UMLClassifierList namesList( m_doc->getConcepts() );
+    UMLClassifierList namesList( m_doc->concepts() );
     foreach (UMLClassifier* obj, namesList) {
-         types << obj->getFullyQualifiedName();
+         types << obj->fullyQualifiedName();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
@@ -550,8 +559,8 @@ void UMLOperationDialog::insertTypesSorted( const QString& type )
 void UMLOperationDialog::insertStereotypesSorted( const QString& type )
 {
     QStringList types;
-    foreach (UMLStereotype* currentSt, m_doc->getStereotypes() ) {
-        types << currentSt->getName();
+    foreach (UMLStereotype* currentSt, m_doc->stereotypes() ) {
+        types << currentSt->name();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
