@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -295,7 +295,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
                 insert(mt_ChangeToClass_Selection, i18n("Change into Class"));
             } else if (type == Uml::wt_Class) {
                 UMLClassifier *umlc = c->classifier();
-                if (umlc->getAbstract() && umlc->attributes() == 0)
+                if (umlc->isAbstract() && umlc->attributes() == 0)
                     insert(mt_ChangeToInterface_Selection, i18n("Change into Interface"));
             }
         }
@@ -554,7 +554,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
         break;
     }//end switch
 
-    bool bCutState = UMLApp::app()->getCutCopyState();
+    bool bCutState = UMLApp::app()->isCutCopyState();
     setActionEnabled( mt_Cut, bCutState );
     setActionEnabled( mt_Copy, bCutState );
     setActionEnabled( mt_Paste, false );
@@ -881,10 +881,10 @@ void ListPopupMenu::insertSubmodelAction()
     }
     UMLFolder *f = dynamic_cast<UMLFolder*>(o);
     if (f == NULL) {
-        uError() << o->getName() << " is not a Folder";
+        uError() << o->name() << " is not a Folder";
         return;
     }
-    QString submodelFile = f->getFolderFile();
+    QString submodelFile = f->folderFile();
     if (submodelFile.isEmpty()) {
         insert(mt_Externalize_Folder);
     }
@@ -962,7 +962,7 @@ void ListPopupMenu::makeClassifierPopup(ClassifierWidget *c)
         insert(mt_Refactoring, Icon_Utils::SmallIcon(Icon_Utils::it_Refactor), i18n("Refactor"));
         insert(mt_ViewCode, Icon_Utils::SmallIcon(Icon_Utils::it_View_Code), i18n("View Code"));
         UMLClassifier *umlc = c->classifier();
-        if (umlc->getAbstract() && umlc->attributes() == 0)
+        if (umlc->isAbstract() && umlc->attributes() == 0)
             insert(mt_ChangeToInterface, i18n("Change into Interface"));
     }
     insert(mt_Properties);
@@ -1668,12 +1668,12 @@ void ListPopupMenu::setupMenu(Menu_Type type)
     }//end switch
 
     if( m_TriggerObjectType == tot_View ) {
-        bool bCutState = UMLApp::app()->getCutCopyState();
-        setActionEnabled( mt_Undo, UMLApp::app()->getUndoEnabled() );
-        setActionEnabled( mt_Redo, UMLApp::app()->getRedoEnabled() );
+        bool bCutState = UMLApp::app()->isCutCopyState();
+        setActionEnabled( mt_Undo, UMLApp::app()->isUndoEnabled() );
+        setActionEnabled( mt_Redo, UMLApp::app()->isRedoEnabled() );
         setActionEnabled( mt_Cut, bCutState );
         setActionEnabled( mt_Copy, bCutState );
-        setActionEnabled( mt_Paste, UMLApp::app()->getPasteState() );
+        setActionEnabled( mt_Paste, UMLApp::app()->isPasteState() );
     }
 
 }
