@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2009                                               *
+ *   copyright (C) 2004-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -80,10 +80,10 @@ UMLObject* findObjectInList(Uml::IDType id, const UMLObjectList& inList)
 {
     for (UMLObjectListIt oit(inList); oit.hasNext(); ) {
         UMLObject *obj = oit.next();
-        if (obj->getID() == id)
+        if (obj->id() == id)
             return obj;
         UMLObject *o;
-        Uml::Object_Type t = obj->getBaseType();
+        Uml::Object_Type t = obj->baseType();
         switch (t) {
         case Uml::ot_Folder:
         case Uml::ot_Package:
@@ -107,10 +107,10 @@ UMLObject* findObjectInList(Uml::IDType id, const UMLObjectList& inList)
             {
                 UMLAssociation *assoc = static_cast<UMLAssociation*>(obj);
                 UMLRole *rA = assoc->getUMLRole(Uml::A);
-                if (rA->getID() == id)
+                if (rA->id() == id)
                     return rA;
                 UMLRole *rB = assoc->getUMLRole(Uml::B);
-                if (rB->getID() == id)
+                if (rB->id() == id)
                     return rB;
             }
             break;
@@ -170,22 +170,22 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
         }
         pkg = dynamic_cast<UMLPackage*>(currentObj);
         if (pkg == NULL)
-            pkg = currentObj->getUMLPackage();
+            pkg = currentObj->umlPackage();
         // Remember packages that we've seen - for avoiding cycles.
         UMLPackageList seenPkgs;
-        for (; pkg; pkg = currentObj->getUMLPackage()) {
+        for (; pkg; pkg = currentObj->umlPackage()) {
             if (nameWithoutFirstPrefix.isEmpty()) {
                 if (caseSensitive) {
-                    if (pkg->getName() == name)
+                    if (pkg->name() == name)
                         return pkg;
-                } else if (pkg->getName().toLower() == name.toLower()) {
+                } else if (pkg->name().toLower() == name.toLower()) {
                     return pkg;
                 }
             }
             if (seenPkgs.indexOf(pkg) != -1) {
                 uError() << "findUMLObject(" << name << "): "
                     << "breaking out of cycle involving "
-                    << pkg->getName();
+                    << pkg->name();
                 break;
             }
             seenPkgs.append(pkg);
@@ -193,12 +193,12 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
             for (UMLObjectListIt oit(objectsInCurrentScope); oit.hasNext(); ) {
                 UMLObject *obj = oit.next();
                 if (caseSensitive) {
-                    if (obj->getName() != name)
+                    if (obj->name() != name)
                         continue;
-                } else if (obj->getName().toLower() != name.toLower()) {
+                } else if (obj->name().toLower() != name.toLower()) {
                     continue;
                 }
-                Uml::Object_Type foundType = obj->getBaseType();
+                Uml::Object_Type foundType = obj->baseType();
                 if (nameWithoutFirstPrefix.isEmpty()) {
                     if (type != Uml::ot_UMLObject && type != foundType) {
                         uDebug() << "findUMLObject: type mismatch for "
@@ -239,12 +239,12 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
     for (UMLObjectListIt oit(inList); oit.hasNext(); ) {
         UMLObject *obj = oit.next();
         if (caseSensitive) {
-            if (obj->getName() != name)
+            if (obj->name() != name)
                 continue;
-        } else if (obj->getName().toLower() != name.toLower()) {
+        } else if (obj->name().toLower() != name.toLower()) {
             continue;
         }
-        Uml::Object_Type foundType = obj->getBaseType();
+        Uml::Object_Type foundType = obj->baseType();
         if (nameWithoutFirstPrefix.isEmpty()) {
             if (type != Uml::ot_UMLObject && type != foundType) {
                 uDebug() << "findUMLObject: type mismatch for "
@@ -277,7 +277,7 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
  */
 void treeViewAddViews(const UMLViewList& viewList)
 {
-    UMLListView* tree = UMLApp::app()->getListView();
+    UMLListView* tree = UMLApp::app()->listView();
     foreach (UMLView* v,  viewList) {
         if (tree->findItem(v->umlScene()->getID()) != NULL) {
             continue;
@@ -293,7 +293,7 @@ void treeViewAddViews(const UMLViewList& viewList)
  */
 void treeViewChangeIcon(UMLObject* object, Icon_Utils::Icon_Type to)
 {
-    UMLListView* tree = UMLApp::app()->getListView();
+    UMLListView* tree = UMLApp::app()->listView();
     tree->changeIconOf(object, to);
 }
 
@@ -303,7 +303,7 @@ void treeViewChangeIcon(UMLObject* object, Icon_Utils::Icon_Type to)
  */
 void treeViewSetCurrentItem(UMLObject* object)
 {
-    UMLListView* tree = UMLApp::app()->getListView();
+    UMLListView* tree = UMLApp::app()->listView();
     UMLListViewItem* item = tree->findUMLObject(object);
     tree->setCurrentItem(item);
 }
@@ -315,9 +315,9 @@ void treeViewSetCurrentItem(UMLObject* object)
  */
 void treeViewMoveObjectTo(UMLObject* container, UMLObject* object)
 {
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem *newParent = listView->findUMLObject(container);
-    listView->moveObject(object->getID(),
+    listView->moveObject(object->id(),
                    Model_Utils::convert_OT_LVT(object),
                    newParent);
 }
@@ -328,7 +328,7 @@ void treeViewMoveObjectTo(UMLObject* container, UMLObject* object)
  */
 UMLObject* treeViewGetCurrentObject()
 {
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem *current = static_cast<UMLListViewItem*>(listView->currentItem());
     return current->getUMLObject();
 }
@@ -340,7 +340,7 @@ UMLObject* treeViewGetCurrentObject()
  */
 UMLPackage* treeViewGetPackageFromCurrent()
 {
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem *parentItem = (UMLListViewItem*)listView->currentItem();
     if (parentItem) {
         Uml::ListView_Type lvt = parentItem->getType();
@@ -361,7 +361,7 @@ UMLPackage* treeViewGetPackageFromCurrent()
  */
 QString treeViewBuildDiagramName(Uml::IDType id)
 {
-    UMLListView *listView = UMLApp::app()->getListView();
+    UMLListView *listView = UMLApp::app()->listView();
     UMLListViewItem* listViewItem = listView->findItem(id);
 
     if (listViewItem) {
@@ -433,7 +433,7 @@ QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString pre
             uWarning() << "unknown object type in umldoc::uniqObjectName()";
         }
     }
-    UMLDoc *doc = UMLApp::app()->getDocument();
+    UMLDoc *doc = UMLApp::app()->document();
     QString name = currentName;
     for (int number = 1; !doc->isUnique(name, parentPkg); ++number)  {
         name = currentName + '_' + QString::number(number);
@@ -474,7 +474,7 @@ bool isCommonXMIAttribute( const QString &tag )
  */
 bool isCommonDataType(QString type)
 {
-    CodeGenerator *gen = UMLApp::app()->getGenerator();
+    CodeGenerator *gen = UMLApp::app()->generator();
     if (gen == NULL)
         return false;
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
@@ -518,8 +518,8 @@ bool isClassifierListitem(Uml::Object_Type type)
  */
 Uml::Model_Type guessContainer(UMLObject *o)
 {
-    Uml::Object_Type ot = o->getBaseType();
-    if (ot == Uml::ot_Package && o->getStereotype() == "subsystem")
+    Uml::Object_Type ot = o->baseType();
+    if (ot == Uml::ot_Package && o->stereotype() == "subsystem")
         return Uml::mt_Component;
     Uml::Model_Type mt = Uml::N_MODELTYPES;
     switch (ot) {
@@ -556,17 +556,17 @@ Uml::Model_Type guessContainer(UMLObject *o)
         case Uml::ot_Association:
             {
                 UMLAssociation *assoc = static_cast<UMLAssociation*>(o);
-                UMLDoc *umldoc = UMLApp::app()->getDocument();
+                UMLDoc *umldoc = UMLApp::app()->document();
                 for (int r = Uml::A; r <= Uml::B; ++r) {
                     UMLObject *roleObj = assoc->getObject((Uml::Role_Type)r);
                     if (roleObj == NULL) {
                         // Ouch! we have been called while types are not yet resolved
                         return Uml::N_MODELTYPES;
                     }
-                    UMLPackage *pkg = roleObj->getUMLPackage();
+                    UMLPackage *pkg = roleObj->umlPackage();
                     if (pkg) {
-                        while (pkg->getUMLPackage()) {  // wind back to root
-                            pkg = pkg->getUMLPackage();
+                        while (pkg->umlPackage()) {  // wind back to root
+                            pkg = pkg->umlPackage();
                         }
                         const Uml::Model_Type m = umldoc->rootFolderType(pkg);
                         if (m != Uml::N_MODELTYPES)
@@ -624,7 +624,7 @@ int stringToDirection(QString input, Uml::Parameter_Direction & result)
  */
 Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningScope)
 {
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
 
     t = t.trimmed();
     if (t.isEmpty())
@@ -665,7 +665,7 @@ Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningSc
 Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningScope,
                             Uml::Visibility *vis /* = 0 */)
 {
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
 
     a = a.simplified();
     if (a.isEmpty())
@@ -739,7 +739,7 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
  */
 Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owningScope)
 {
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
 
     m = m.simplified();
     if (m.isEmpty())
@@ -1230,7 +1230,7 @@ Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt)
  */
 Uml::ListView_Type convert_OT_LVT(UMLObject *o)
 {
-    Uml::Object_Type ot = o->getBaseType();
+    Uml::Object_Type ot = o->baseType();
     Uml::ListView_Type type =  Uml::lvt_Unknown;
     switch(ot) {
     case Uml::ot_UseCase:
@@ -1251,7 +1251,7 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o)
 
     case Uml::ot_Folder:
         {
-            UMLDoc *umldoc = UMLApp::app()->getDocument();
+            UMLDoc *umldoc = UMLApp::app()->document();
             UMLFolder *f = static_cast<UMLFolder*>(o);
             do {
                 const Uml::Model_Type mt = umldoc->rootFolderType(f);
@@ -1277,8 +1277,8 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o)
                     }
                     return type;
                 }
-            } while ((f = static_cast<UMLFolder*>(f->getUMLPackage())) != NULL);
-            uError() << "convert_OT_LVT(" << o->getName()
+            } while ((f = static_cast<UMLFolder*>(f->umlPackage())) != NULL);
+            uError() << "convert_OT_LVT(" << o->name()
                 << "): internal error - object is not properly nested in folder";
         }
         break;
