@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006-2009                                                *
+ *  copyright (C) 2006-2010                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -158,18 +158,18 @@ UMLObject* createNewUMLObject(Uml::Object_Type type, const QString &name,
  *                        The default is to ask for the new name.
  */
 UMLObject* createUMLObject(Uml::Object_Type type, const QString &n,
-                           UMLPackage *parentPkg /* = NULL */,
+                           UMLPackage *parentPkg /* = 0 */,
                            bool solicitNewName /* = true */)
 {
-    UMLDoc *doc = UMLApp::app()->getDocument();
+    UMLDoc *doc = UMLApp::app()->document();
     if (parentPkg == NULL) {
         if (type == Uml::ot_Datatype) {
-            parentPkg = doc->getDatatypeFolder();
+            parentPkg = doc->datatypeFolder();
         } else {
             Uml::Model_Type mt = Model_Utils::convert_OT_MT(type);
             uDebug() << "Object_Factory::createUMLObject(" << n << "): "
                 << "parentPkg is not set, assuming Model_Type " << mt;
-            parentPkg = doc->getRootFolder(mt);
+            parentPkg = doc->rootFolder(mt);
         }
     }
     if (!n.isEmpty()) {
@@ -195,7 +195,7 @@ UMLObject* createUMLObject(Uml::Object_Type type, const QString &n,
                                i18n("Invalid Name"));
             continue;
         }
-        CodeGenerator *codegen = UMLApp::app()->getGenerator();
+        CodeGenerator *codegen = UMLApp::app()->generator();
         if (codegen != NULL && codegen->isReservedKeyword(name)) {
             KMessageBox::error(0, i18n("This is a reserved keyword for the language of the configured code generator."),
                                i18n("Reserved Keyword"));
@@ -315,9 +315,9 @@ UMLObject* makeObjectFromXMI(const QString& xmiTag,
         pObject = new UMLClassifier();
     } else if (Uml::tagEq(xmiTag, "Package")) {
         if (!stereoID.isEmpty()) {
-            UMLDoc *doc = UMLApp::app()->getDocument();
+            UMLDoc *doc = UMLApp::app()->document();
             UMLObject *stereo = doc->findStereotypeById(STR2ID(stereoID));
-            if (stereo && stereo->getName() == "folder")
+            if (stereo && stereo->name() == "folder")
                 pObject = new UMLFolder();
         }
         if (pObject == NULL)
