@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -116,11 +116,11 @@ QMenu* UMLApp::findMenu(const QString& name)
 UMLApp::UMLApp(QWidget* parent) : KXmlGuiWindow(parent)
 {
     s_instance   = this;
-    m_pDocWindow = NULL;
+    m_pDocWindow = 0;
     m_config     = KGlobal::config();
-    m_listView   = NULL;
-    m_langSelect = NULL;
-    m_zoomSelect = NULL;
+    m_listView   = 0;
+    m_langSelect = 0;
+    m_zoomSelect = 0;
     m_loading    = false;
     m_clipTimer  = 0;
     m_copyTimer  = 0;
@@ -265,11 +265,11 @@ void UMLApp::initActions()
 
     QAction* genWizard = actionCollection()->addAction("generation_wizard");
     genWizard->setText(i18n("&Code Generation Wizard..."));
-    connect(genWizard, SIGNAL( triggered( bool ) ), this, SLOT( generationWizard() ));
+    connect(genWizard, SIGNAL( triggered( bool ) ), this, SLOT( slotExecGenerationWizard() ));
 
     QAction* genAll = actionCollection()->addAction("generate_all");
     genAll->setText(i18n("&Generate All Code"));
-    connect(genAll, SIGNAL( triggered( bool ) ), this, SLOT( generateAllCode() ));
+    connect(genAll, SIGNAL( triggered( bool ) ), this, SLOT( slotGenerateAllCode() ));
 
     setProgLangAction(Uml::pl_ActionScript, "ActionScript",    "setLang_actionscript");
     setProgLangAction(Uml::pl_Ada,          "Ada",             "setLang_ada");
@@ -405,7 +405,6 @@ void UMLApp::initActions()
     viewShowGrid = actionCollection()->add<KToggleAction>("view_show_grid");
     viewShowGrid->setText(i18n("S&how Grid"));
     connect(viewShowGrid, SIGNAL( triggered( bool ) ), this, SLOT( slotCurrentViewToggleShowGrid() ));
-    viewShowGrid->setCheckedState(KGuiItem(i18n("&Hide Grid")));
 
     deleteDiagram = actionCollection()->addAction( "view_delete" );
     deleteDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Delete) );
@@ -540,7 +539,7 @@ void UMLApp::initActions()
 void UMLApp::slotZoomSliderMoved(int value)
 {
     int zoom = (int)(value*0.01);
-    getCurrentView()->setZoom(zoom*zoom);
+    currentView()->setZoom(zoom*zoom);
 }
 
 /**
@@ -558,7 +557,7 @@ void UMLApp::slotZoom100()
  */
 void UMLApp::setZoom(int zoom)
 {
-    getCurrentView()->setZoom(zoom);
+    currentView()->setZoom(zoom);
 }
 
 /**
@@ -570,7 +569,7 @@ void UMLApp::slotSetZoom(QAction* action)
 {
     QVariant var = action->data();
     if (var.canConvert<int>()) {
-        getCurrentView()->setZoom(var.toInt());
+        currentView()->setZoom(var.toInt());
     }
 }
 
@@ -597,7 +596,7 @@ void UMLApp::setupZoomMenu()
 {
     m_zoomSelect->clear();
 
-    int currentZoom = getCurrentView()->currentZoom();
+    int currentZoom = currentView()->currentZoom();
 
     m_zoomSelect->addAction(createZoomAction(33, currentZoom));
     m_zoomSelect->addAction(createZoomAction(50, currentZoom));
@@ -658,7 +657,7 @@ void UMLApp::initView()
     m_tabWidget = new KTabWidget(this);
     m_tabWidget->setAutomaticResizeTabs(true);
     m_tabWidget->setTabsClosable(true);
-    connect(m_tabWidget, SIGNAL(closeRequest(QWidget*)), SLOT(slotDeleteDiagram(QWidget*)));
+    connect(m_tabWidget, SIGNAL(closeRequest(QWidget*)), SLOT(slotCloseDiagram(QWidget*)));
 
     m_newSessionButton = new QToolButton(m_tabWidget);
     m_newSessionButton->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Tab_New));
@@ -746,7 +745,7 @@ void UMLApp::openDocumentFile(const KUrl& url)
  * KMainWindow instance.
  * Used by the View class to access the document object's methods.
  */
-UMLDoc *UMLApp::getDocument() const
+UMLDoc *UMLApp::document() const
 {
     return m_doc;
 }
@@ -756,7 +755,7 @@ UMLDoc *UMLApp::getDocument() const
  *
  * @return  The listview being used.
  */
-UMLListView* UMLApp::getListView()
+UMLListView* UMLApp::listView() const
 {
     return m_listView;
 }
@@ -800,14 +799,17 @@ void UMLApp::saveOptions()
         UmbrelloSettings::setLastFile(  m_doc->url().prettyUrl() );
     }
 
-    UmbrelloSettings::setImageMimeType(  getImageMimeType() );
+    UmbrelloSettings::setImageMimeType(  imageMimeType() );
 
     UmbrelloSettings::setUseFillColor(  optionState.uiState.useFillColor );
     UmbrelloSettings::setFillColor(  optionState.uiState.fillColor );
     UmbrelloSettings::setLineColor(  optionState.uiState.lineColor );
     UmbrelloSettings::setLineWidth(  optionState.uiState.lineWidth );
+    UmbrelloSettings::setTextColor( optionState.uiState.textColor );
     UmbrelloSettings::setShowDocWindow(  m_documentationDock->isVisible() );
     UmbrelloSettings::setUiFont(  optionState.uiState.font );
+    UmbrelloSettings::setBackgroundColor( optionState.uiState.backgroundColor );
+    UmbrelloSettings::setGridDotColor( optionState.uiState.gridDotColor );
 
     UmbrelloSettings::setShowVisibility(  optionState.classState.showVisibility );
     UmbrelloSettings::setShowAtts( optionState.classState.showAtts);
@@ -1254,7 +1256,7 @@ void UMLApp::slotEditCut()
     slotStatusMsg(i18n("Cutting selection..."));
     //FIXME bug 59774 this fromview isn't very reliable.
     //when cutting diagrams it is set to true even though it shouldn't be
-    bool fromview = (getCurrentView() && getCurrentView()->umlScene()->getSelectCount());
+    bool fromview = (currentView() && currentView()->umlScene()->getSelectCount());
     if ( editCutCopy(fromview) ) {
         emit sigCutSuccessful();
         slotDeleteSelectedWidget();
@@ -1269,7 +1271,7 @@ void UMLApp::slotEditCut()
 void UMLApp::slotEditCopy()
 {
     slotStatusMsg(i18n("Copying selection to clipboard..."));
-    bool  fromview = (getCurrentView() && getCurrentView()->getSelectCount());
+    bool  fromview = (currentView() && currentView()->getSelectCount());
     editCutCopy( fromview );
     resetStatusMsg();
     m_doc->setModified( true );
@@ -1391,7 +1393,7 @@ void UMLApp::slotEntityRelationshipDiagram()
  */
 void UMLApp::slotAlignLeft()
 {
-    getCurrentView()->alignLeft();
+    currentView()->alignLeft();
 }
 
 /**
@@ -1399,7 +1401,7 @@ void UMLApp::slotAlignLeft()
  */
 void UMLApp::slotAlignRight()
 {
-    getCurrentView()->alignLeft();
+    currentView()->alignLeft();
 }
 
 /**
@@ -1407,7 +1409,7 @@ void UMLApp::slotAlignRight()
  */
 void UMLApp::slotAlignTop()
 {
-    getCurrentView()->alignTop();
+    currentView()->alignTop();
 }
 
 /**
@@ -1415,7 +1417,7 @@ void UMLApp::slotAlignTop()
  */
 void UMLApp::slotAlignBottom()
 {
-    getCurrentView()->alignBottom();
+    currentView()->alignBottom();
 }
 
 /**
@@ -1423,7 +1425,7 @@ void UMLApp::slotAlignBottom()
  */
 void UMLApp::slotAlignVerticalMiddle()
 {
-    getCurrentView()->alignVerticalMiddle();
+    currentView()->alignVerticalMiddle();
 }
 
 /**
@@ -1431,7 +1433,7 @@ void UMLApp::slotAlignVerticalMiddle()
  */
 void UMLApp::slotAlignHorizontalMiddle()
 {
-    getCurrentView()->alignHorizontalMiddle();
+    currentView()->alignHorizontalMiddle();
 }
 
 /**
@@ -1439,7 +1441,7 @@ void UMLApp::slotAlignHorizontalMiddle()
  */
 void UMLApp::slotAlignVerticalDistribute()
 {
-    getCurrentView()->alignVerticalDistribute();
+    currentView()->alignVerticalDistribute();
 }
 
 /**
@@ -1447,7 +1449,7 @@ void UMLApp::slotAlignVerticalDistribute()
  */
 void UMLApp::slotAlignHorizontalDistribute()
 {
-    getCurrentView()->alignHorizontalDistribute();
+    currentView()->alignHorizontalDistribute();
 }
 
 /**
@@ -1455,11 +1457,21 @@ void UMLApp::slotAlignHorizontalDistribute()
  *
  * @return  The toolbar being used.
  */
-WorkToolBar* UMLApp::getWorkToolBar()
+WorkToolBar* UMLApp::workToolBar() const
 {
     return m_toolsbar;
 }
 
+/**
+ * Returns the doc window used.
+ *
+ * @return the doc window being used
+ */
+DocWindow* UMLApp::docWindow() const
+{
+    return m_pDocWindow;
+}
+
 /**
  * Sets whether the program has been modified.
  * This will change how the program saves/exits.
@@ -1473,7 +1485,7 @@ void UMLApp::setModified(bool modified)
     //if anything else needs to be done on a mofication, put it here
 
     // printing should be possible whenever there is something to print
-    if ( m_loading == false && modified == true && getCurrentView() )  {
+    if ( m_loading == false && modified == true && currentView() )  {
         enablePrint(true);
     }
 
@@ -1572,7 +1584,7 @@ void UMLApp::slotClipDataChanged()
  */
 void UMLApp::slotCopyChanged()
 {
-    if (m_listView->getSelectedCount() || (getCurrentView() && getCurrentView()->getSelectCount())) {
+    if (m_listView->getSelectedCount() || (currentView() && currentView()->getSelectCount())) {
         editCopy->setEnabled(true);
         editCut->setEnabled(true);
     }
@@ -1615,7 +1627,7 @@ void UMLApp::slotApplyPrefs()
         if (stackBrowsing != tabBrowsing) {
             // Diagram Representation Modified
             UMLView* currentView;
-            UMLViewList views = m_doc->getViewIterator();
+            UMLViewList views = m_doc->viewIterator();
 
             if (tabBrowsing) {
                 currentView = static_cast<UMLView*>(m_viewStack->currentWidget());
@@ -1624,8 +1636,9 @@ void UMLApp::slotApplyPrefs()
 
                 foreach (UMLView *view, views) {
                     m_viewStack->removeWidget(view);
-                    m_tabWidget->addTab(view, view->getName());
-                    m_tabWidget->setTabIcon(m_tabWidget->indexOf(view), Icon_Utils::iconSet(view->getType()));
+                    int tabIndex = m_tabWidget->addTab(view, view->getName());
+                    m_tabWidget->setTabIcon(tabIndex, Icon_Utils::iconSet(view->getType()));
+                    m_tabWidget->setTabToolTip(tabIndex, view->getName());
                 }
                 m_layout->addWidget(m_tabWidget);
                 m_tabWidget->show();
@@ -1657,7 +1670,7 @@ void UMLApp::slotApplyPrefs()
  *
  * @return  True if Undo is enabled.
  */
-bool UMLApp::getUndoEnabled()
+bool UMLApp::isUndoEnabled() const
 {
     return editUndo->isEnabled();
 }
@@ -1667,7 +1680,7 @@ bool UMLApp::getUndoEnabled()
  *
  * @return  True if Redo is enabled.
  */
-bool UMLApp::getRedoEnabled()
+bool UMLApp::isRedoEnabled() const
 {
     return editRedo->isEnabled();
 }
@@ -1677,7 +1690,7 @@ bool UMLApp::getRedoEnabled()
  *
  * @return  True if Paste is enabled.
  */
-bool UMLApp::getPasteState()
+bool UMLApp::isPasteState() const
 {
     return editPaste->isEnabled();
 }
@@ -1687,7 +1700,7 @@ bool UMLApp::getPasteState()
  *
  * @return  True if Cut/Copy is enabled.
  */
-bool UMLApp::getCutCopyState()
+bool UMLApp::isCutCopyState() const
 {
     return editCopy->isEnabled();
 }
@@ -1754,7 +1767,10 @@ void UMLApp::readOptionState()
     optionState.uiState.fillColor =  UmbrelloSettings::fillColor();
     optionState.uiState.lineColor =  UmbrelloSettings::lineColor();
     optionState.uiState.lineWidth =  UmbrelloSettings::lineWidth();
+    optionState.uiState.textColor = UmbrelloSettings::textColor();
     optionState.uiState.font =  UmbrelloSettings::uiFont();
+    optionState.uiState.backgroundColor = UmbrelloSettings::backgroundColor();
+    optionState.uiState.gridDotColor = UmbrelloSettings::gridDotColor();
 
     optionState.classState.showVisibility =  UmbrelloSettings::showVisibility();
     optionState.classState.showAtts =  UmbrelloSettings::showAtts();
@@ -1821,7 +1837,7 @@ void UMLApp::readOptionState()
  */
 void UMLApp::viewCodeDocument(UMLClassifier* classifier)
 {
-    CodeGenerator * currentGen = getGenerator();
+    CodeGenerator * currentGen = generator();
     if (currentGen && classifier) {
         if (!dynamic_cast<SimpleCodeGenerator*>(currentGen)) {
             CodeDocument *cdoc = currentGen->findCodeDocumentByClassifier(classifier);
@@ -1862,7 +1878,7 @@ void UMLApp::refactor(UMLClassifier* classifier)
 /**
  * Returns the default code generation policy.
  */
-CodeGenerationPolicy *UMLApp::getCommonPolicy()
+CodeGenerationPolicy *UMLApp::commonPolicy() const
 {
     return m_commoncodegenpolicy;
 }
@@ -1878,7 +1894,7 @@ void UMLApp::setPolicyExt(CodeGenPolicyExt *policy)
 /**
  * Returns the CodeGenPolicyExt object.
  */
-CodeGenPolicyExt *UMLApp::getPolicyExt()
+CodeGenPolicyExt *UMLApp::policyExt() const
 {
     return m_policyext;
 }
@@ -1902,7 +1918,7 @@ CodeGenerator *UMLApp::setGenerator(Uml::Programming_Language pl)
     // does the code generator already exist?
     // then simply return that
     if (m_codegen) {
-        if (m_codegen->getLanguage() == pl) {
+        if (m_codegen->language() == pl) {
             return m_codegen;
         }
         delete m_codegen;  // ATTENTION! remove all refs to it or its policy first
@@ -1926,7 +1942,7 @@ CodeGenerator *UMLApp::setGenerator(Uml::Programming_Language pl)
  *
  * @return  Pointer to the CodeGenerator.
  */
-CodeGenerator* UMLApp::getGenerator()
+CodeGenerator* UMLApp::generator() const
 {
     return m_codegen;
 }
@@ -1949,7 +1965,7 @@ bool UMLApp::isSimpleCodeGeneratorActive()
 /**
  * Generate code for all classes.
  */
-void UMLApp::generateAllCode()
+void UMLApp::slotGenerateAllCode()
 {
     if (m_codegen) {
         m_codegen->writeCodeToFile();
@@ -1959,7 +1975,7 @@ void UMLApp::generateAllCode()
 /**
  * Runs the code generation wizard.
  */
-void UMLApp::generationWizard()
+void UMLApp::slotExecGenerationWizard()
 {
     QPointer<CodeGenerationWizard> wizard = new CodeGenerationWizard(0 /*classList*/);
     wizard->exec();
@@ -2083,7 +2099,7 @@ void UMLApp::setActiveLanguage(Uml::Programming_Language pl)
 /**
  * Get the language for import and code generation.
  */
-Uml::Programming_Language UMLApp::getActiveLanguage()
+Uml::Programming_Language UMLApp::activeLanguage() const
 {
     return m_activeLanguage;
 }
@@ -2105,7 +2121,7 @@ bool UMLApp::activeLanguageIsCaseSensitive()
  */
 QString UMLApp::activeLanguageScopeSeparator()
 {
-    Uml::Programming_Language pl = getActiveLanguage();
+    Uml::Programming_Language pl = activeLanguage();
     if (pl == Uml::pl_Ada ||
         pl == Uml::pl_CSharp ||
         pl == Uml::pl_Pascal ||
@@ -2122,7 +2138,7 @@ QString UMLApp::activeLanguageScopeSeparator()
  */
 void UMLApp::slotCurrentViewClearDiagram()
 {
-    getCurrentView()->clearDiagram();
+    currentView()->clearDiagram();
 }
 
 /**
@@ -2130,8 +2146,8 @@ void UMLApp::slotCurrentViewClearDiagram()
  */
 void UMLApp::slotCurrentViewToggleSnapToGrid()
 {
-    getCurrentView()->toggleSnapToGrid();
-    viewSnapToGrid->setChecked( getCurrentView()->getSnapToGrid() );
+    currentView()->toggleSnapToGrid();
+    viewSnapToGrid->setChecked( currentView()->getSnapToGrid() );
 }
 
 /**
@@ -2139,8 +2155,8 @@ void UMLApp::slotCurrentViewToggleSnapToGrid()
  */
 void UMLApp::slotCurrentViewToggleShowGrid()
 {
-    getCurrentView()->toggleShowGrid();
-    viewShowGrid->setChecked( getCurrentView()->getShowSnapGrid() );
+    currentView()->toggleShowGrid();
+    viewShowGrid->setChecked( currentView()->getShowSnapGrid() );
 }
 
 /**
@@ -2148,7 +2164,7 @@ void UMLApp::slotCurrentViewToggleShowGrid()
  */
 void UMLApp::slotCurrentViewExportImage()
 {
-    getCurrentView()->getImageExporter()->exportView();
+    currentView()->getImageExporter()->exportView();
 }
 
 /**
@@ -2164,7 +2180,7 @@ void UMLApp::slotAllViewsExportImage()
  */
 void UMLApp::slotCurrentViewProperties()
 {
-    getCurrentView()->showPropDialog();
+    currentView()->showPropDialog();
 }
 
 /**
@@ -2181,9 +2197,9 @@ void UMLApp::setDiagramMenuItemsState(bool bState)
     viewExportImage->setEnabled( bState );
     viewProperties->setEnabled( bState );
     filePrint->setEnabled( bState );
-    if ( getCurrentView() ) {
-        viewSnapToGrid->setChecked( getCurrentView()->getSnapToGrid() );
-        viewShowGrid->setChecked( getCurrentView()->getShowSnapGrid() );
+    if ( currentView() ) {
+        viewSnapToGrid->setChecked( currentView()->getSnapToGrid() );
+        viewShowGrid->setChecked( currentView()->getShowSnapGrid() );
     }
 }
 
@@ -2207,7 +2223,7 @@ void UMLApp::slotUpdateViews()
 
     menu->clear();
 
-    UMLViewList views = m_doc->getViewIterator();
+    UMLViewList views = m_doc->viewIterator();
     foreach (UMLView *view , views ) {
         menu->addAction(view->getName(), view, SLOT(slotShowView()));
         view->fileLoaded();
@@ -2242,7 +2258,7 @@ void UMLApp::slotImportClasses()
     // because the user might decide to choose a language different from
     // the active language (by using the "All Files" option).
     QString preselectedExtension;
-    const Uml::Programming_Language pl = m_codegen->getLanguage();
+    const Uml::Programming_Language pl = m_codegen->language();
     if (pl == Uml::pl_IDL) {
         preselectedExtension = i18n("*.idl|IDL Files (*.idl)");
     } else if (pl == Uml::pl_Python) {
@@ -2269,7 +2285,7 @@ void UMLApp::slotImportProject()
 {
     QStringList listFile;
 
-    QPointer<ImportProjectDlg> importDlg = new ImportProjectDlg(&listFile, m_codegen->getLanguage(), this);
+    QPointer<ImportProjectDlg> importDlg = new ImportProjectDlg(&listFile, m_codegen->language(), this);
     if (importDlg->exec() == KDialog::Accepted) {
         importFiles(&listFile);
     }
@@ -2299,7 +2315,7 @@ void UMLApp::slotAddDefaultDatatypes()
  */
 void UMLApp::slotCurrentViewChanged()
 {
-    UMLView *view = getCurrentView();
+    UMLView *view = currentView();
     if (view) {
         connect(view, SIGNAL( sigShowGridToggled(bool) ),
                 this, SLOT( slotShowGridToggled(bool) ) );
@@ -2329,7 +2345,7 @@ void UMLApp::slotShowGridToggled(bool gridOn)
  */
 void UMLApp::slotSelectAll()
 {
-    getCurrentView()->selectAll();
+    currentView()->selectAll();
 }
 
 /**
@@ -2337,8 +2353,8 @@ void UMLApp::slotSelectAll()
  */
 void UMLApp::slotDeleteSelectedWidget()
 {
-    if ( getCurrentView() ) {
-        getCurrentView()->deleteSelection();
+    if ( currentView() ) {
+        currentView()->deleteSelection();
     } 
     else {
         uWarning() << " trying to delete widgets when there is no current view (see bug 59774)";
@@ -2346,20 +2362,26 @@ void UMLApp::slotDeleteSelectedWidget()
 }
 
 /**
- * Deletes the current diagram.
+ * Deletes the current diagram. Called from menu action.
+ */
+void UMLApp::slotDeleteDiagram()
+{
+    m_doc->removeDiagram( currentView()->getID() );
+}
+
+/**
+ * Close the current diagram. Clicked on tab close button.
  * @param tab   Widget's tab to close
  */
-void UMLApp::slotDeleteDiagram(QWidget* tab)
+void UMLApp::slotCloseDiagram(QWidget* tab)
 {
-    if (tab == NULL) {  // called from menu action
-        m_doc->removeDiagram( getCurrentView()->getID() );
-    }
-    else {  // clicked on close button
+    if (tab) {
         UMLView* view = (UMLView*)tab;
-        if (view != getCurrentView()) {
+        if (view != currentView()) {
             setCurrentView(view);
         }
-        m_doc->removeDiagram( view->getID() );
+        m_tabWidget->removeTab(m_tabWidget->indexOf(view));
+        view->setIsOpen(false);
     }
 }
 
@@ -2368,7 +2390,7 @@ void UMLApp::slotDeleteDiagram(QWidget* tab)
  * If the activeLanguage is not found in the KConfig then use Uml::pl_Cpp
  * as the default.
  */
-Uml::Programming_Language UMLApp::getDefaultLanguage()
+Uml::Programming_Language UMLApp::defaultLanguage()
 {
     Settings::OptionState& optionState = Settings::getOptionState();
     return optionState.generalState.defaultLanguage;
@@ -2383,8 +2405,8 @@ void UMLApp::initGenerator()
         delete m_codegen;
         m_codegen = NULL;
     }
-    Uml::Programming_Language defaultLanguage = getDefaultLanguage();
-    setActiveLanguage(defaultLanguage);
+    Uml::Programming_Language defLanguage = defaultLanguage();
+    setActiveLanguage(defLanguage);
 }
 
 /**
@@ -2511,7 +2533,7 @@ void UMLApp::newDocument()
  * Returns the widget used as the parent for UMLViews.
  * @return  The main view widget.
  */
-QWidget* UMLApp::getMainViewWidget()
+QWidget* UMLApp::mainViewWidget()
 {
     Settings::OptionState& optionState = Settings::getOptionState();
     if ( optionState.generalState.tabdiagrams ) {
@@ -2533,16 +2555,19 @@ void UMLApp::setCurrentView(UMLView* view)
     m_view = view;
     if (view == NULL) {
         uDebug() << "view is NULL";
+        docWindow()->newDocumentation();
         return;
     }
 
     Settings::OptionState optionState = Settings::getOptionState();
     if (optionState.generalState.tabdiagrams) {
-        if ( m_tabWidget->indexOf(view) < 0 ) {
-            m_tabWidget->addTab(view, view->getName());
-            m_tabWidget->setTabIcon(m_tabWidget->indexOf(view), Icon_Utils::iconSet(view->getType()));
+        int tabIndex = m_tabWidget->indexOf(view);
+        if ((tabIndex < 0) && view->isOpen()) {
+            tabIndex = m_tabWidget->addTab(view, view->getName());
+            m_tabWidget->setTabIcon(tabIndex, Icon_Utils::iconSet(view->getType()));
+            m_tabWidget->setTabToolTip(tabIndex, view->getName());
         }
-        m_tabWidget->setCurrentIndex(m_tabWidget->indexOf(view));
+        m_tabWidget->setCurrentIndex(tabIndex);
     }
     else {
         if (m_viewStack->indexOf(view) < 0) {
@@ -2557,6 +2582,7 @@ void UMLApp::setCurrentView(UMLView* view)
     if (lvitem) {
         m_listView->setCurrentItem(lvitem);
     }
+    uDebug() << "name=" << view->getName() << ", isOpen=" << view->isOpen() << ", id=" << ID2STR(view->getID());
 }
 
 /**
@@ -2564,7 +2590,7 @@ void UMLApp::setCurrentView(UMLView* view)
  * This may return a null pointer (when no view was previously
  * specified.)
  */
-UMLView* UMLApp::getCurrentView()
+UMLView* UMLApp::currentView() const
 {
     return m_view;
 }
@@ -2583,7 +2609,7 @@ void UMLApp::setImageMimeType(QString const & mimeType)
  * images.
  * @return  The default MIME type for images.
  */
-QString UMLApp::getImageMimeType() const
+QString UMLApp::imageMimeType() const
 {
     return m_imageMimeType;
 }
@@ -2610,7 +2636,7 @@ void UMLApp::slotChangeTabLeft()
         m_tabWidget->setCurrentIndex( m_tabWidget->currentIndex() - 1 );
         return;
     }
-    UMLViewList views = m_doc->getViewIterator();
+    UMLViewList views = m_doc->viewIterator();
     UMLView *currView = m_view;
     int viewIndex = 0;
     if ((viewIndex = views.indexOf(currView)) < 0) {
@@ -2640,10 +2666,10 @@ void UMLApp::slotChangeTabRight()
         m_tabWidget->setCurrentIndex( m_tabWidget->currentIndex() + 1 );
         return;
     }
-    UMLViewList views = m_doc->getViewIterator();
+    UMLViewList views = m_doc->viewIterator();
     UMLView *currView = m_view;
     int viewIndex = 0;
-    if (( viewIndex = views.indexOf(currView) ) < 0) {
+    if ((viewIndex = views.indexOf(currView)) < 0) {
         uError() << "currView not found in viewlist";
         return;
     }
@@ -2735,7 +2761,7 @@ KTabWidget* UMLApp::tabWidget()
  *
  * @return The text in the status bar.
  */
-QString UMLApp::getStatusBarMsg()
+QString UMLApp::statusBarMsg()
 {
     return statusBar()->itemText(1);
 }
@@ -2822,4 +2848,12 @@ void UMLApp::endMacro()
     m_hasBegunMacro = false;
 }
 
+/**
+ * Return the config data.
+ */
+KConfig* UMLApp::config()
+{
+    return m_config.data();
+}
+
 #include "uml.moc"
