@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,17 +5,19 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLCLASSIFIERLIST_H
 #define UMLCLASSIFIERLIST_H
 
-#include <qptrlist.h>
+#include <QtCore/QList>
 
 // forward declaration
 class UMLClassifier;
 
-typedef QPtrList<UMLClassifier> UMLClassifierList;
-typedef QPtrListIterator<UMLClassifier> UMLClassifierListIt;
+typedef QList<UMLClassifier*> UMLClassifierList;
+typedef QListIterator<UMLClassifier*> UMLClassifierListIt;
 
 #endif
